Re: [OE-core] [PATCH 0/3] Fix rpm signing with GPG v2.1

2017-02-23 Thread Markus Lehtonen
On 23/02/2017, 17.58, "akuster808"  wrote:

Markus,


On 02/23/2017 02:24 AM, Markus Lehtonen wrote:
> This patchset makes signing work with all versions of GPG.  Previously, 
rpm
> package signing in oe-core was not working with GPG v2.1 (which is 
becoming
> more widespread). This was caused by a change in passphrase dialogue 
handling
> of GPG.

Off hand, do you know if Morty would benefit from this?

Yes it would. Same problem with GPG 2.1 there
  - Markus



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] deprecated.bbclass: Add a PNDEPRECATED variable for recipes

2017-02-23 Thread Khem Raj
On Thu, Feb 23, 2017 at 8:00 PM Joe MacDonald 
wrote:

> Based on the blacklist behaviour, recipes can be tagged as deprecated.
> Such recipes will produce a warning message when included in a build but
> unlike blacklisted recipes, the build will continue.


Perhaps this should also be documented in manuals

>
>
> Signed-off-by: Joe MacDonald 
> ---
>
> I threw this together a long time ago and never got around to sending it
> out for
> consideration, but after the excitement last week and this, I got thinking
> about
> it again and thought it might be useful.  My specific use-case for this is
> recipes I see in meta-networking that I know are largely abandonware but
> that I
> don't want to completely throw out without giving some kind of heads up.
> Obviously this is purely informational, there's no mechanism set up for
> purging
> deprecated recipes, that's intended to be a maintainer activity, but the
> idea
> would be that the maintainer would flag a recipe as deprecated (probably
> when
> it's become more trouble than it seems to be worth) and thereafter users
> would
> have fair warning that this thing is on notice.  If nobody speaks up
> within some
> amount of time the maintainer considers reasonable (I'm thinking a Yocto
> release
> cycle) then it's fair game to remove the recipe in question.
>
>  meta/classes/deprecated.bbclass| 16 
>  meta/conf/distro/defaultsetup.conf |  3 ++-
>  2 files changed, 18 insertions(+), 1 deletion(-)
>  create mode 100644 meta/classes/deprecated.bbclass
>
> diff --git a/meta/classes/deprecated.bbclass
> b/meta/classes/deprecated.bbclass
> new file mode 100644
> index 000..3dcdadb
> --- /dev/null
> +++ b/meta/classes/deprecated.bbclass
> @@ -0,0 +1,16 @@
> +# To use the deprecated recipe check, a distribution should
> +# include this class in the INHERIT_DISTRO
> +#
> +# Features:
> +#
> +# * To add a package to the deprecated list, set:
> +#   PNDEPRECATED[pn] = "message"
> +#
> +
> +addtask check_deprecated before do_fetch
> +python do_check_deprecated () {
> +deprecated = d.getVarFlag('PNDEPRECATED', d.getVar('PN', True), False)
> +
> +if deprecated:
> +bb.warn("Recipe is deprecated: ", (deprecated))
> +}
> diff --git a/meta/conf/distro/defaultsetup.conf
> b/meta/conf/distro/defaultsetup.conf
> index ca2f917..16ece3a 100644
> --- a/meta/conf/distro/defaultsetup.conf
> +++ b/meta/conf/distro/defaultsetup.conf
> @@ -20,5 +20,6 @@ CACHE = "${TMPDIR}/cache/${TCMODE}-${TCLIBC}${@['', '/'
> + str(d.getVar('MACHINE'
>  USER_CLASSES ?= ""
>  PACKAGE_CLASSES ?= "package_ipk"
>  INHERIT_BLACKLIST = "blacklist"
> +INHERIT_DEPRECATED = "deprecated"
>  INHERIT_DISTRO ?= "debian devshell sstate license remove-libtool"
> -INHERIT += "${PACKAGE_CLASSES} ${USER_CLASSES} ${INHERIT_DISTRO}
> ${INHERIT_BLACKLIST}"
> +INHERIT += "${PACKAGE_CLASSES} ${USER_CLASSES} ${INHERIT_DISTRO}
> ${INHERIT_BLACKLIST} ${INHERIT_DEPRECATED}"
> --
> 1.9.1
>
> --
> ___
> Openembedded-core mailing list
> Openembedded-core@lists.openembedded.org
> http://lists.openembedded.org/mailman/listinfo/openembedded-core
>
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] deprecated.bbclass: Add a PNDEPRECATED variable for recipes

2017-02-23 Thread Joe MacDonald
Based on the blacklist behaviour, recipes can be tagged as deprecated.
Such recipes will produce a warning message when included in a build but
unlike blacklisted recipes, the build will continue.

Signed-off-by: Joe MacDonald 
---

I threw this together a long time ago and never got around to sending it out for
consideration, but after the excitement last week and this, I got thinking about
it again and thought it might be useful.  My specific use-case for this is
recipes I see in meta-networking that I know are largely abandonware but that I
don't want to completely throw out without giving some kind of heads up.
Obviously this is purely informational, there's no mechanism set up for purging
deprecated recipes, that's intended to be a maintainer activity, but the idea
would be that the maintainer would flag a recipe as deprecated (probably when
it's become more trouble than it seems to be worth) and thereafter users would
have fair warning that this thing is on notice.  If nobody speaks up within some
amount of time the maintainer considers reasonable (I'm thinking a Yocto release
cycle) then it's fair game to remove the recipe in question.

 meta/classes/deprecated.bbclass| 16 
 meta/conf/distro/defaultsetup.conf |  3 ++-
 2 files changed, 18 insertions(+), 1 deletion(-)
 create mode 100644 meta/classes/deprecated.bbclass

diff --git a/meta/classes/deprecated.bbclass b/meta/classes/deprecated.bbclass
new file mode 100644
index 000..3dcdadb
--- /dev/null
+++ b/meta/classes/deprecated.bbclass
@@ -0,0 +1,16 @@
+# To use the deprecated recipe check, a distribution should
+# include this class in the INHERIT_DISTRO
+#
+# Features:
+#
+# * To add a package to the deprecated list, set:
+#   PNDEPRECATED[pn] = "message"
+#
+
+addtask check_deprecated before do_fetch
+python do_check_deprecated () {
+deprecated = d.getVarFlag('PNDEPRECATED', d.getVar('PN', True), False)
+
+if deprecated:
+bb.warn("Recipe is deprecated: ", (deprecated))
+}
diff --git a/meta/conf/distro/defaultsetup.conf 
b/meta/conf/distro/defaultsetup.conf
index ca2f917..16ece3a 100644
--- a/meta/conf/distro/defaultsetup.conf
+++ b/meta/conf/distro/defaultsetup.conf
@@ -20,5 +20,6 @@ CACHE = "${TMPDIR}/cache/${TCMODE}-${TCLIBC}${@['', '/' + 
str(d.getVar('MACHINE'
 USER_CLASSES ?= ""
 PACKAGE_CLASSES ?= "package_ipk"
 INHERIT_BLACKLIST = "blacklist"
+INHERIT_DEPRECATED = "deprecated"
 INHERIT_DISTRO ?= "debian devshell sstate license remove-libtool"
-INHERIT += "${PACKAGE_CLASSES} ${USER_CLASSES} ${INHERIT_DISTRO} 
${INHERIT_BLACKLIST}"
+INHERIT += "${PACKAGE_CLASSES} ${USER_CLASSES} ${INHERIT_DISTRO} 
${INHERIT_BLACKLIST} ${INHERIT_DEPRECATED}"
-- 
1.9.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2] ovmf: increase path length limit

2017-02-23 Thread Patrick Ohly
The VfrCompile tool has a hard-coded maximum length for path names
which turned out to be too small by around 20 characters in the
Yocto autobuilder setup. Increasing the maximum by a factor of 4
is relatively easy and makes the problem less likely.

Signed-off-by: Patrick Ohly 
---
 .../VfrCompile-increase-path-length-limit.patch| 33 ++
 meta/recipes-core/ovmf/ovmf_git.bb |  1 +
 2 files changed, 34 insertions(+)
 create mode 100644 
meta/recipes-core/ovmf/ovmf/VfrCompile-increase-path-length-limit.patch

diff --git 
a/meta/recipes-core/ovmf/ovmf/VfrCompile-increase-path-length-limit.patch 
b/meta/recipes-core/ovmf/ovmf/VfrCompile-increase-path-length-limit.patch
new file mode 100644
index 000..bb12d8b
--- /dev/null
+++ b/meta/recipes-core/ovmf/ovmf/VfrCompile-increase-path-length-limit.patch
@@ -0,0 +1,33 @@
+From c7722d10c7bcf6be0adcf54abb1d406599dd7914 Mon Sep 17 00:00:00 2001
+From: Patrick Ohly 
+Date: Fri, 24 Feb 2017 01:40:02 +0100
+Subject: [PATCH] VfrCompile: increase path length limit
+
+The VfrCompile tool has a hard-coded maximum length for path names
+which turned out to be too small by around 20 characters in the Yocto
+autobuilder setup. Increasing the maximum by a factor of 4 is
+relatively easy and makes the problem less likely.
+
+Upstream-Status: Inappropriate [configuration]
+
+Signed-off-by: Patrick Ohly 
+---
+ BaseTools/Source/C/VfrCompile/EfiVfr.h | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/BaseTools/Source/C/VfrCompile/EfiVfr.h 
b/BaseTools/Source/C/VfrCompile/EfiVfr.h
+index d187902..9ad4a7b 100644
+--- a/BaseTools/Source/C/VfrCompile/EfiVfr.h
 b/BaseTools/Source/C/VfrCompile/EfiVfr.h
+@@ -19,7 +19,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER 
EXPRESS OR IMPLIED.
+ #include "Common/UefiInternalFormRepresentation.h"
+ #include "Common/MdeModuleHii.h"
+ 
+-#define MAX_PATH 255
++#define MAX_PATH 1023
+ #define MAX_VFR_LINE_LEN 4096
+ 
+ #define EFI_IFR_MAX_LENGTH   0xFF
+-- 
+2.1.4
+
diff --git a/meta/recipes-core/ovmf/ovmf_git.bb 
b/meta/recipes-core/ovmf/ovmf_git.bb
index 6b3a597..a658c9d 100644
--- a/meta/recipes-core/ovmf/ovmf_git.bb
+++ b/meta/recipes-core/ovmf/ovmf_git.bb
@@ -14,6 +14,7 @@ SRC_URI = "git://github.com/tianocore/edk2.git;branch=master \
file://0001-BaseTools-Force-tools-variables-to-host-toolchain.patch \
file://0002-ovmf-update-path-to-native-BaseTools.patch \
file://0003-BaseTools-makefile-adjust-to-build-in-under-bitbake.patch \
+   file://VfrCompile-increase-path-length-limit.patch \
 "
 
 SRC_URI_append_class-target = " \
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 2/2] ovmf: increase path length limit

2017-02-23 Thread Patrick Ohly
On Thu, 2017-02-23 at 18:48 +0100, Patrick Ohly wrote:
> The VfrCompile tool has a hard-coded maximum length for path names
> which turned out to be too small by around 20 characters in the
> Yocto autobuilder setup. Increasing the maximum by a factor of 4
> is relatively easy and makes the problem less likely.
> 
> Signed-off-by: Patrick Ohly 
> ---
>  meta/recipes-core/ovmf/ovmf_git.bb | 5 +
>  1 file changed, 5 insertions(+)
> 
> diff --git a/meta/recipes-core/ovmf/ovmf_git.bb 
> b/meta/recipes-core/ovmf/ovmf_git.bb
> index 6b3a597..76e836a 100644
> --- a/meta/recipes-core/ovmf/ovmf_git.bb
> +++ b/meta/recipes-core/ovmf/ovmf_git.bb
> @@ -50,6 +50,11 @@ COMPATIBLE_HOST='(i.86|x86_64).*'
>  OVMF_SECURE_BOOT_EXTRA_FLAGS ??= ""
>  OVMF_SECURE_BOOT_FLAGS = "-DSECURE_BOOT_ENABLE=TRUE 
> ${OVMF_SECURE_BOOT_EXTRA_FLAGS}"
>  
> +do_patch[postfuncs] += "fix_path_len"
> +fix_path_len () {
> +sed -i -e 's/^#define MAX_PATH.*255/#define MAX_PATH 1023/' 
> ${S}/BaseTools/Source/C/VfrCompile/EfiVfr.h
> +}

I've used sed here because it was easy. I'll also send a version which
uses a proper patch. Just beware of the line encoding issues. The patch
really must have CR line ends, otherwise it won't apply to the source.

It might be safer to pull V2 of the ovmf patch from:
https://github.com/pohly/openembedded-core/commits/ovmf

-- 
Best Regards, Patrick Ohly

The content of this message is my personal opinion only and although
I am an employee of Intel, the statements I make here in no way
represent Intel's position on the issue, nor am I authorized to speak
on behalf of Intel on this matter.



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH v2 1/1] kernel.bbclass: Make sanity check opt-out and provide easy opt-out

2017-02-23 Thread Cal Sullivan

On 02/23/2017 03:27 PM, Cal Sullivan wrote:



On 02/23/2017 03:07 PM, Burton, Ross wrote:


On 23 February 2017 at 22:32, California Sullivan 
<california.l.sulli...@intel.com 
<mailto:california.l.sulli...@intel.com>> wrote:


The only change from V1 to V2 is the updated commit message, changing
AUTOINC to AUTOREV and adding the blurb about impacting outside
recipes.

I also agree with Richard in that this is a significant
functionality change
and should not be backported.


I failed to say that I suspected this patch was to blame for SDK 
generation failing on the autobuilder earlier.  Can you try 
generating a eSDK (bitbake core-image-minimal -c populate_sdk_ext) 
 with this patch?


Ross
Will do. Any specific configuration I should use, or should it fail in 
most/all situations?


Thanks,
Cal




[clsulliv@clsulliv build]$ bitbake core-image-minimal -c populate_sdk_ext
WARNING: Host distribution "fedora-23" has not been validated with this 
version of the build system; you may possibly experience unexpected 
failures. It is recommended that you use a tested distribution.
Loading cache: 100% 
|##| 
Time: 0:00:00

Loaded 1346 entries from dependency cache.
NOTE: Resolving any missing task queue dependencies

Build Configuration:
BB_VERSION= "1.33.1"
BUILD_SYS = "x86_64-linux"
NATIVELSBSTRING   = "universal"
TARGET_SYS= "x86_64-poky-linux"
MACHINE   = "intel-corei7-64"
DISTRO= "poky"
DISTRO_VERSION= "2.2+snapshot-20170223"
TUNE_FEATURES = "m64 corei7"
TARGET_FPU= ""
meta
meta-poky
meta-yocto-bsp= 
"clsulliv/sanity:53c2449017a3312a2e65720a23ef654924eef0b4"

meta-intel= "master:5153dad2fa695bbb579c03ff795ef649269e8420"

Initialising tasks: 100% 
|#| 
Time: 0:00:06

NOTE: Executing SetScene Tasks
NOTE: Executing RunQueue Tasks
NOTE: Tasks Summary: Attempted 3362 tasks of which 2752 didn't need to 
be rerun and all succeeded.


Summary: There was 1 WARNING message shown.


I'll rerun the build with no meta-intel and qemux86 overnight.

p.s., upgrading my fedora system now :)

---
Cal
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH v2 1/1] kernel.bbclass: Make sanity check opt-out and provide easy opt-out

2017-02-23 Thread Cal Sullivan



On 02/23/2017 03:07 PM, Burton, Ross wrote:


On 23 February 2017 at 22:32, California Sullivan 
> wrote:


The only change from V1 to V2 is the updated commit message, changing
AUTOINC to AUTOREV and adding the blurb about impacting outside
recipes.

I also agree with Richard in that this is a significant
functionality change
and should not be backported.


I failed to say that I suspected this patch was to blame for SDK 
generation failing on the autobuilder earlier.  Can you try generating 
a eSDK (bitbake core-image-minimal -c populate_sdk_ext)  with this patch?


Ross
Will do. Any specific configuration I should use, or should it fail in 
most/all situations?


Thanks,
Cal
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 00/68] Consolidated Pull

2017-02-23 Thread Richard Purdie
On Thu, 2017-02-23 at 17:30 +, Ross Burton wrote:
> Long consolidated pull, 100% green on the AB (excluding distrodata).
> 
> Note that this contains large amounts of master-next but master-next
> does
> include some patches that are superceded by this series, so I
> recommend
> reviewing this and then rebasing master-next.

I know this one was a pain to stabilise, merged, thanks!

Richard
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH v2 1/1] kernel.bbclass: Make sanity check opt-out and provide easy opt-out

2017-02-23 Thread Burton, Ross
On 23 February 2017 at 22:32, California Sullivan <
california.l.sulli...@intel.com> wrote:

> The only change from V1 to V2 is the updated commit message, changing
> AUTOINC to AUTOREV and adding the blurb about impacting outside recipes.
>
> I also agree with Richard in that this is a significant functionality
> change
> and should not be backported.
>

I failed to say that I suspected this patch was to blame for SDK generation
failing on the autobuilder earlier.  Can you try generating a eSDK (bitbake
core-image-minimal -c populate_sdk_ext)  with this patch?

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 20/24] libiconv: remove recipe

2017-02-23 Thread Burton, Ross
On 23 February 2017 at 22:47, Khem Raj  wrote:

> > ERROR: Nothing PROVIDES 'virtual/nativesdk-libiconv' (but
> > virtual:nativesdk:/home/pokybuild/yocto-autobuilder/
> yocto-worker/nightly-qa-extras/build/meta/recipes-core/gettext/
> gettext_0.19.8.1.bb
> > DEPENDS on or otherwise requires it)
>
> It seems that nativesdk-glibc is not providing it. We
> should fix that
>

Oh, this was with  SDKMACHINE = "i686-mingw32" which likely makes a
difference but it's too late for me to make an informed opinion. :)

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 20/24] libiconv: remove recipe

2017-02-23 Thread Khem Raj
On Thu, Feb 23, 2017 at 2:12 PM, Burton, Ross  wrote:
>
> On 22 February 2017 at 14:51, Alexander Kanavin
>  wrote:
>>
>> It was in use only when uclibc was used, and so serves no purpose anymore.
>> Both glibc and musl provide their own implementation.
>
> Either this isn't entirely accurate or we need more RPROVIDES set:
>
> ERROR: Nothing PROVIDES 'virtual/nativesdk-libiconv' (but
> virtual:nativesdk:/home/pokybuild/yocto-autobuilder/yocto-worker/nightly-qa-extras/build/meta/recipes-core/gettext/gettext_0.19.8.1.bb
> DEPENDS on or otherwise requires it)

It seems that nativesdk-glibc is not providing it. We
should fix that

>
> Ross
>
> --
> ___
> Openembedded-core mailing list
> Openembedded-core@lists.openembedded.org
> http://lists.openembedded.org/mailman/listinfo/openembedded-core
>
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 1/1] kernel.bbclass: Make sanity check opt-out and provide easy opt-out

2017-02-23 Thread California Sullivan
Having no opt-out method and adding the task to linux-yocto.inc was
causing issues. For example, linux-yocto-dev would often fail because
it uses AUTOREV with no way to dynamically change the PV.

Add a variable to turn off the sanity check to easily opt out.
Add the task to the kernel build by default so that it is not both
opt-in and opt out.
Set the opt-out variable in linux-yocto-dev, fixing the issue with
AUTOREV.

Note that this change *will* impact non linux-yocto kernel recipes, and
will require recipes using kernel.bbclass to either set the correct PV
or opt-out of the check.

Signed-off-by: California Sullivan 
---
The only change from V1 to V2 is the updated commit message, changing
AUTOINC to AUTOREV and adding the blurb about impacting outside recipes.

I also agree with Richard in that this is a significant functionality change
and should not be backported.

 meta/classes/kernel.bbclass  | 8 +++-
 meta/recipes-kernel/linux/linux-yocto-dev.bb | 1 +
 meta/recipes-kernel/linux/linux-yocto.inc| 1 -
 3 files changed, 8 insertions(+), 2 deletions(-)

diff --git a/meta/classes/kernel.bbclass b/meta/classes/kernel.bbclass
index 97cba92..731776e 100644
--- a/meta/classes/kernel.bbclass
+++ b/meta/classes/kernel.bbclass
@@ -325,6 +325,10 @@ do_install[prefuncs] += "package_get_auto_pr"
 
 # Must be ran no earlier than after do_kernel_checkout or else Makefile won't 
be in ${S}/Makefile
 do_kernel_version_sanity_check() {
+   if [ "x${KERNEL_VERSION_SANITY_SKIP}" = "x1" ]; then
+   exit 0
+   fi
+
# The Makefile determines the kernel version shown at runtime
# Don't use KERNEL_VERSION because the headers it grabs the version 
from aren't generated until do_compile
VERSION=$(grep "^VERSION =" ${S}/Makefile | sed s/.*=\ *//)
@@ -348,11 +352,13 @@ do_kernel_version_sanity_check() {
reg="${reg}${EXTRAVERSION}"
 
if [ -z `echo ${PV} | grep -E "${reg}"` ]; then
-   bbfatal "Package Version (${PV}) does not match of kernel being 
built (${vers}). Please update the PV variable to match the kernel source."
+   bbfatal "Package Version (${PV}) does not match of kernel being 
built (${vers}). Please update the PV variable to match the kernel source or 
set KERNEL_VERSION_SANITY_SKIP=\"1\" in your recipe."
fi
exit 0
 }
 
+addtask kernel_version_sanity_check after do_kernel_metadata 
do_kernel_checkout before do_compile
+
 addtask shared_workdir after do_compile before do_compile_kernelmodules
 addtask shared_workdir_setscene
 
diff --git a/meta/recipes-kernel/linux/linux-yocto-dev.bb 
b/meta/recipes-kernel/linux/linux-yocto-dev.bb
index a4e02db..d5579b2 100644
--- a/meta/recipes-kernel/linux/linux-yocto-dev.bb
+++ b/meta/recipes-kernel/linux/linux-yocto-dev.bb
@@ -43,3 +43,4 @@ KERNEL_FEATURES_append_qemux86=" cfg/sound.scc 
cfg/paravirt_kvm.scc"
 KERNEL_FEATURES_append_qemux86-64=" cfg/sound.scc"
 KERNEL_FEATURES_append = " ${@bb.utils.contains("TUNE_FEATURES", "mx32", " 
cfg/x32.scc", "" ,d)}"
 
+KERNEL_VERSION_SANITY_SKIP = "1"
diff --git a/meta/recipes-kernel/linux/linux-yocto.inc 
b/meta/recipes-kernel/linux/linux-yocto.inc
index 556546f..3ea3e40 100644
--- a/meta/recipes-kernel/linux/linux-yocto.inc
+++ b/meta/recipes-kernel/linux/linux-yocto.inc
@@ -64,7 +64,6 @@ do_install_append(){
 }
 
 # extra tasks
-addtask kernel_version_sanity_check after do_kernel_metadata 
do_kernel_checkout before do_compile
 addtask kernel_link_images after do_compile before do_strip
 addtask validate_branches before do_patch after do_kernel_checkout
 addtask kernel_configcheck after do_configure before do_compile
-- 
2.5.5

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] State of bitbake world, Failed tasks 2017-02-23

2017-02-23 Thread Martin Jansa
== Number of issues - stats ==
{| class='wikitable'
!|Date   !!colspan='3'|Failed tasks 
!!colspan='6'|Failed depencencies!!|Signatures
!!colspan='12'|QA !!Comment
|-
||  ||qemuarm   ||qemux86   ||qemux86_64
||qemuarm||max||min ||qemux86||max||min ||all   ||already-stripped  
||libdir||textrel   ||build-deps||file-rdeps
||version-going-backwards   ||host-user-contaminated
||installed-vs-shipped  ||unknown-configure-option  ||symlink-to-sysroot
||invalid-pkgconfig ||pkgname   ||  
|-
||2017-02-23||2 ||2 ||2 ||N/A   ||N/A   ||N/A   ||N/A   ||N/A   
||N/A   ||0 ||0 ||0 ||0 ||0 
||1 ||6 ||0 ||1 ||0 
||0 ||0 ||0 ||  
|}

http://www.openembedded.org/wiki/Bitbake_World_Status

== Failed tasks 2017-02-23 ==

INFO: jenkins-job.sh-1.8.18 Complete log available at 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.report.20170223_120915.log

=== common (2) ===
* 
openembedded-core/meta/recipes-extended/parted/parted_3.2.bb:do_compile_ptest_base
* 
openembedded-core/meta/recipes-support/apr/apr_1.5.2.bb:do_compile_ptest_base

=== common-x86 (0) ===

=== qemuarm (0) ===

=== qemux86 (0) ===

=== qemux86_64 (0) ===

=== Number of failed tasks (6) ===
{| class=wikitable
|-
|| qemuarm  || 2 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemuarm.20170223_084059.log/
 || http://errors.yoctoproject.org/Errors/Build/32887/
|-
|| qemux86  || 2 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemux86.20170223_084103.log/
 || http://errors.yoctoproject.org/Errors/Build/32888/
|-
|| qemux86_64   || 2 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemux86-64.20170223_102158.log/
 || http://errors.yoctoproject.org/Errors/Build/32889/
|}

=== PNBLACKLISTs (370) ===

=== QA issues (8) ===
{| class=wikitable
!| Count||Issue
|-
||0 ||already-stripped
|-
||0 ||build-deps
|-
||0 ||host-user-contaminated
|-
||0 ||invalid-pkgconfig
|-
||0 ||libdir
|-
||0 ||pkgname
|-
||0 ||symlink-to-sysroot
|-
||0 ||textrel
|-
||0 ||unknown-configure-option
|-
||1 ||file-rdeps
|-
||1 ||installed-vs-shipped
|-
||6 ||version-going-backwards
|}



=== Incorrect PACKAGE_ARCH or sstate signatures (0) ===

Complete log: 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.signatures.20170223_102010.log/

No issues detected


== Tested changes (not included in master yet) - bitbake ==
latest upstream commit: 
5ef2cb5 runqueue: Fix collapsed setscene dependency tree
not included in master yet: 
04ef978 world-image: add extra target

== Tested changes (not included in master yet) - openembedded-core ==
latest upstream commit: 
def3800 layer.conf: bump version for change in eSDK selftest behaviour
not included in master yet: 
32dccb6 qemux86: Add identical qemux86copy variant for tests
313a260 sstate-sysroot-cruft.sh: Extend the whitelist
c57759d recipes: Replace "cp -a" with "cp -R --no-dereference 
--preserve=mode,links"
4c99c85 buildhistory.bbclass: metadata-revs show repo parent
ca6f284 metadata-revs: provide more information
48f5dad report-error: Allow to upload reports automatically
5a94912 flex: upgrade to 2.6.3
2c57675 Revert "flex: upgrade to 2.6.3"
e505914 Revert "flex: upgrade to 2.6.2"
3b4b417 core-image-tiny-initramfs: drop wic from IMAGE_FSTYPES

== Tested changes (not included in master yet) - meta-openembedded ==
latest upstream commit: 
ec8d5fc pidgin: add missing dependencies and unblacklist
not included in master yet: 
eb79791 netcat-openbsd: fix implicit dependency on pkg-config
933b3e3 libsdl-mixer: add pkgconfig to inherit and unblacklist
1acd54a libsdl2-mixer: add pkgconfig to inherit and unblacklist
374debc gtk-engines: add glib-2.0-native to DEPENDS an unblacklist
378b290 gtkmathview: libxslt -> libxslt-native in DEPENDS and unblacklist
b738ce4 fontforge: add gettext to inherit and unblacklist
37f0c82 fontforge: update 20150824 -> 20161012
e964e30 postgresql: use gettext bbclass and unblacklist
33b6944 postgresql: update 9.4.10 -> 9.4.11
5eb1d86 libsdl2-ttf: add pkgconfig to inherit and unblacklist
885e79c libsdl-ttf: fix and unblacklist
a152f69 python-paho-mqtt: update to version 1.2
9e46e25 python-cloudeebus: remove obsolete recipe
68e9a57 python-autobahn: remove obsolete recipe
d3c3a17 python-pyro4: update to version 4.55
c5da99b python-greenlet: update to version 0.4.12
3e23ed7 python-vobject: update to version 0.9.4.1
673aadf python-serpent: update to version 1.18.1
c813c3e python-lxml: update to version 3.7.3
383351f python-pyasn1: update to version 0.2.2
8681632 python-jinja2: update to version 2.9.5
41b1306 python-pymisp: update to version 2.4.65
a08602a 

Re: [OE-core] [PATCH 20/24] libiconv: remove recipe

2017-02-23 Thread Burton, Ross
On 22 February 2017 at 14:51, Alexander Kanavin <
alexander.kana...@linux.intel.com> wrote:

> It was in use only when uclibc was used, and so serves no purpose anymore.
> Both glibc and musl provide their own implementation.
>
Either this isn't entirely accurate or we need more RPROVIDES set:

ERROR: Nothing PROVIDES 'virtual/nativesdk-libiconv' (but
virtual:nativesdk:/home/pokybuild/yocto-autobuilder/yocto-worker/nightly-qa-extras/build/meta/recipes-core/gettext/
gettext_0.19.8.1.bb DEPENDS on or otherwise requires it)

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 1/1] selftest/runtime-test.py: Add test to check PACKAGE_FEED_URIS var

2017-02-23 Thread Alexander Kanavin

On 02/20/2017 08:54 PM, Humberto Ibarra wrote:

 features = 'INHERIT += "testimage"\n'
 features += 'TEST_SUITES = "ping ssh selftest"\n'
+features += 'PACKAGE_FEED_URIS = "http://192.168.7.1:8080"\n'


Can you make the assumption that the IP address will be exactly this? 
I'm seeing various IP addresses in autobuilder logs when for example 
testimages are being tested simultaneously, and they're not always 
192.168.7.1.


Alex
--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] State of bitbake world, Failed tasks 2017-02-22

2017-02-23 Thread Martin Jansa
== Number of issues - stats ==
{| class='wikitable'
!|Date   !!colspan='3'|Failed tasks 
!!colspan='6'|Failed depencencies!!|Signatures
!!colspan='12'|QA !!Comment
|-
||  ||qemuarm   ||qemux86   ||qemux86_64
||qemuarm||max||min ||qemux86||max||min ||all   ||already-stripped  
||libdir||textrel   ||build-deps||file-rdeps
||version-going-backwards   ||host-user-contaminated
||installed-vs-shipped  ||unknown-configure-option  ||symlink-to-sysroot
||invalid-pkgconfig ||pkgname   ||  
|-
||2017-02-22||4 ||4 ||4 ||N/A   ||N/A   ||N/A   ||N/A   ||N/A   
||N/A   ||0 ||0 ||0 ||0 ||0 
||0 ||354   ||0 ||0 ||0 
||0 ||0 ||0 ||  
|}

http://www.openembedded.org/wiki/Bitbake_World_Status

== Failed tasks 2017-02-22 ==

INFO: jenkins-job.sh-1.8.18 Complete log available at 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.report.20170223_005128.log

=== common (4) ===
* 
meta-openembedded/meta-gnome/recipes-gnome/abiword/abiword_3.0.1.bb:do_configure
* 
meta-smartphone/meta-android/recipes-android/android-tools/android-tools_4.2.2.bb:do_patch
* 
openembedded-core/meta/recipes-extended/parted/parted_3.2.bb:do_compile_ptest_base
* 
openembedded-core/meta/recipes-support/apr/apr_1.5.2.bb:do_compile_ptest_base

=== common-x86 (0) ===

=== qemuarm (0) ===

=== qemux86 (0) ===

=== qemux86_64 (0) ===

=== Number of failed tasks (12) ===
{| class=wikitable
|-
|| qemuarm  || 4 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemuarm.20170222_155436.log/
 || 
|-
|| qemux86  || 4 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemux86.20170222_155444.log/
 || http://errors.yoctoproject.org/Errors/Build/32829/
|-
|| qemux86_64   || 4 || 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.world.qemux86-64.20170222_174852.log/
 || http://errors.yoctoproject.org/Errors/Build/32830/
|}

=== PNBLACKLISTs (369) ===

=== QA issues (354) ===
{| class=wikitable
!| Count||Issue
|-
||0 ||already-stripped
|-
||0 ||build-deps
|-
||0 ||file-rdeps
|-
||0 ||host-user-contaminated
|-
||0 ||installed-vs-shipped
|-
||0 ||invalid-pkgconfig
|-
||0 ||libdir
|-
||0 ||pkgname
|-
||0 ||symlink-to-sysroot
|-
||0 ||textrel
|-
||0 ||unknown-configure-option
|-
||354   ||version-going-backwards
|}



=== Incorrect PACKAGE_ARCH or sstate signatures (0) ===

Complete log: 
http://logs.nslu2-linux.org/buildlogs/oe/world/pyro/log.signatures.20170222_173415.log/

No issues detected

== Tested changes (not included in master yet) - bitbake ==
latest upstream commit: 
5ef2cb5 runqueue: Fix collapsed setscene dependency tree
not included in master yet: 
04ef978 world-image: add extra target

== Tested changes (not included in master yet) - openembedded-core ==
latest upstream commit: 
def3800 layer.conf: bump version for change in eSDK selftest behaviour
not included in master yet: 
32dccb6 qemux86: Add identical qemux86copy variant for tests
313a260 sstate-sysroot-cruft.sh: Extend the whitelist
c57759d recipes: Replace "cp -a" with "cp -R --no-dereference 
--preserve=mode,links"
4c99c85 buildhistory.bbclass: metadata-revs show repo parent
ca6f284 metadata-revs: provide more information
48f5dad report-error: Allow to upload reports automatically
5a94912 flex: upgrade to 2.6.3
2c57675 Revert "flex: upgrade to 2.6.3"
e505914 Revert "flex: upgrade to 2.6.2"
3b4b417 core-image-tiny-initramfs: drop wic from IMAGE_FSTYPES

== Tested changes (not included in master yet) - meta-openembedded ==
latest upstream commit: 
ec8d5fc pidgin: add missing dependencies and unblacklist
not included in master yet: 
eb79791 netcat-openbsd: fix implicit dependency on pkg-config
933b3e3 libsdl-mixer: add pkgconfig to inherit and unblacklist
1acd54a libsdl2-mixer: add pkgconfig to inherit and unblacklist
374debc gtk-engines: add glib-2.0-native to DEPENDS an unblacklist
378b290 gtkmathview: libxslt -> libxslt-native in DEPENDS and unblacklist
f27fc74 abiword: unblacklist - gtkmathview is back
2c473f0 fontforge: add gettext to inherit and unblacklist
4dfa2e0 fontforge: update 20150824 -> 20161012
0f204dc postgresql: use gettext bbclass and aublacklist
06c9fb2 postgresql: update 9.4.10 -> 9.4.11
78deb80 libsdl2-ttf: add pkgconfig to inherit and unblacklist
250c84b libsdl-ttf: fix and unblacklist
193e93d python-paho-mqtt: update to version 1.2
0d27137 python-cloudeebus: remove obsolete recipe

== Tested changes (not included in master yet) - meta-qt5 ==
latest upstream commit: 
ee301d8 populate_sdk_qt5: use _append operator
not included in master yet: 
170f2b7 qtbase-native: nativesdk-qtbase: remove patch that breaks mkspec 
setting for SDK

== 

[OE-core] [PATCH] wic: Prevent duplicate entries on fstab

2017-02-23 Thread Fabio Berton
Add function to read fstab and return all mount points. This function
is useful to _update_fstab doesn't duplicate entries in /etc/fstab.

Signed-off-by: Fabio Berton 
---
 scripts/lib/wic/plugins/imager/direct.py | 21 -
 1 file changed, 20 insertions(+), 1 deletion(-)

diff --git a/scripts/lib/wic/plugins/imager/direct.py 
b/scripts/lib/wic/plugins/imager/direct.py
index 481d24d5ba..570dbbbf79 100644
--- a/scripts/lib/wic/plugins/imager/direct.py
+++ b/scripts/lib/wic/plugins/imager/direct.py
@@ -97,6 +97,25 @@ class DirectPlugin(ImagerPlugin):
 finally:
 self.cleanup()
 
+def _get_fstab_mountpoints(self):
+""" Read file /etc/fstab and returns all mountpoints."""
+image_rootfs = self.rootfs_dir.get("ROOTFS_DIR")
+if not image_rootfs:
+return
+
+fstab_path = image_rootfs + "/etc/fstab"
+if not os.path.isfile(fstab_path):
+return
+
+with open(fstab_path) as fp:
+mp = []
+for l in fp:
+if not l.startswith("#"):
+valid_mp = l.replace("\t", " ").split()
+if len(valid_mp) >= 2:
+mp.append(valid_mp[1])
+return mp
+
 def _write_fstab(self, image_rootfs):
 """overriden to generate fstab (temporarily) in rootfs. This is called
 from _create, make sure it doesn't get called from
@@ -125,7 +144,7 @@ class DirectPlugin(ImagerPlugin):
 updated = False
 for part in parts:
 if not part.realnum or not part.mountpoint \
-   or part.mountpoint in ("/", "/boot"):
+   or part.mountpoint in self._get_fstab_mountpoints():
 continue
 
 # mmc device partitions are named mmcblk0p1, mmcblk0p2..
-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v1] oeqa/sdk/cases:Adds validation for SDK compatibility tests

2017-02-23 Thread Francisco Pedraza
Added validation for SDK compatibility tests with eSDK.
buildcvs, buildiptables, gcc, perl, python and buildgalculator based on target 
manifest file.
Running with: $ bitbake  -c testsdkext
[YOCTO #9090]

Signed-off-by: Francisco Pedraza 
---
 meta/lib/oeqa/sdk/cases/buildcvs.py| 8 
 meta/lib/oeqa/sdk/cases/buildgalculator.py | 4 +++-
 meta/lib/oeqa/sdk/cases/buildiptables.py   | 8 
 meta/lib/oeqa/sdk/cases/gcc.py | 6 --
 4 files changed, 15 insertions(+), 11 deletions(-)

diff --git a/meta/lib/oeqa/sdk/cases/buildcvs.py 
b/meta/lib/oeqa/sdk/cases/buildcvs.py
index 1ffd8cb..4b6a79d 100644
--- a/meta/lib/oeqa/sdk/cases/buildcvs.py
+++ b/meta/lib/oeqa/sdk/cases/buildcvs.py
@@ -15,10 +15,10 @@ class BuildCvsTest(OESDKTestCase):
 self.project.download_archive()
 
 machine = self.td.get("MACHINE")
-if not (self.tc.hasHostPackage("packagegroup-cross-canadian-%s" % 
machine) or 
-self.tc.hasHostPackage("gcc-runtime") or
-self.tc.hasHostPackage("libgcc") or
-self.tc.hasHostPackage("gcc-sanitizers")):
+if not (self.tc.hasTargetPackage("packagegroup-cross-canadian-%s" % 
machine) or 
+self.tc.hasTargetPackage("gcc-runtime") or
+self.tc.hasTargetPackage("libgcc") or
+self.tc.hasTargetPackage("gcc-sanitizers")):
 raise unittest.SkipTest("SDK doesn't contain a cross-canadian 
toolchain")
 
 def test_cvs(self):
diff --git a/meta/lib/oeqa/sdk/cases/buildgalculator.py 
b/meta/lib/oeqa/sdk/cases/buildgalculator.py
index 42e8ddb..76874ad 100644
--- a/meta/lib/oeqa/sdk/cases/buildgalculator.py
+++ b/meta/lib/oeqa/sdk/cases/buildgalculator.py
@@ -9,7 +9,9 @@ class GalculatorTest(OESDKTestCase):
 @classmethod
 def setUpClass(self):
 if not (self.tc.hasTargetPackage("gtk+3") or\
-self.tc.hasTargetPackage("libgtk-3.0")):
+self.tc.hasTargetPackage("libgtk-3.0") or
+self.tc.hasTargetPackage("gtk+") or
+self.tc.hasTargetPackage("matchbox-config-gtk")):
 raise unittest.SkipTest("GalculatorTest class: SDK don't support 
gtk+3")
 
 def test_galculator(self):
diff --git a/meta/lib/oeqa/sdk/cases/buildiptables.py 
b/meta/lib/oeqa/sdk/cases/buildiptables.py
index 621fb55..d7a0e6a 100644
--- a/meta/lib/oeqa/sdk/cases/buildiptables.py
+++ b/meta/lib/oeqa/sdk/cases/buildiptables.py
@@ -17,10 +17,10 @@ class BuildIptablesTest(OESDKTestCase):
 
 machine = self.td.get("MACHINE")
 
-if not (self.tc.hasHostPackage("packagegroup-cross-canadian-%s" % 
machine) or
-self.tc.hasHostPackage("gcc-runtime") or
-self.tc.hasHostPackage("libgcc") or
-self.tc.hasHostPackage("gcc-sanitizers")):
+if not (self.tc.hasTargetPackage("packagegroup-cross-canadian-%s" % 
machine) or
+self.tc.hasTargetPackage("gcc-runtime") or
+self.tc.hasTargetPackage("libgcc") or
+self.tc.hasTargetPackage("gcc-sanitizers")):
 raise unittest.SkipTest("SDK doesn't contain a cross-canadian 
toolchain")
 
 def test_iptables(self):
diff --git a/meta/lib/oeqa/sdk/cases/gcc.py b/meta/lib/oeqa/sdk/cases/gcc.py
index d869247..a183cfc 100644
--- a/meta/lib/oeqa/sdk/cases/gcc.py
+++ b/meta/lib/oeqa/sdk/cases/gcc.py
@@ -18,8 +18,10 @@ class GccCompileTest(OESDKTestCase):
 
 def setUp(self):
 machine = self.td.get("MACHINE")
-if not (self.tc.hasHostPackage("packagegroup-cross-canadian-%s" % 
machine) or
-self.tc.hasHostPackage("gcc-runtime")):
+if not (self.tc.hasTargetPackage("packagegroup-cross-canadian-%s" % 
machine) or
+self.tc.hasTargetPackage("gcc-runtime") or
+self.tc.hasTargetPackage("libgcc") or 
+self.tc.hasTargetPackage("gcc-sanitizers")):
 raise unittest.SkipTest("GccCompileTest class: SDK doesn't contain 
a cross-canadian toolchain")
 
 def test_gcc_compile(self):
-- 
1.8.3.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 1/2] acpica: fix compilation with musl

2017-02-23 Thread Patrick Ohly
Manipulating stderr after freopen() fails as done by upstream
does not work with musl. The replacement is Unix specific
and uses open()/dup2().

Signed-off-by: Patrick Ohly 
---
 meta/recipes-extended/acpica/acpica_20150515.bb|  1 +
 .../files/manipulate-fds-instead-of-FILE.patch | 71 ++
 2 files changed, 72 insertions(+)
 create mode 100644 
meta/recipes-extended/acpica/files/manipulate-fds-instead-of-FILE.patch

diff --git a/meta/recipes-extended/acpica/acpica_20150515.bb 
b/meta/recipes-extended/acpica/acpica_20150515.bb
index c23b491..b55f353 100644
--- a/meta/recipes-extended/acpica/acpica_20150515.bb
+++ b/meta/recipes-extended/acpica/acpica_20150515.bb
@@ -19,6 +19,7 @@ DEPENDS = "bison flex"
 SRC_URI = "https://acpica.org/sites/acpica/files/acpica-unix2-${PV}.tar.gz \
 file://no-werror.patch \
 file://rename-yy_scan_string-manually.patch \
+file://manipulate-fds-instead-of-FILE.patch \
 "
 SRC_URI[md5sum] = "2bc4a7ccc82de9df9fa964f784ecb29c"
 SRC_URI[sha256sum] = 
"61204ec56d71bc9bfa2ee2ade4c66f7e8541772ac72ef8ccc20b3f339cc96374"
diff --git 
a/meta/recipes-extended/acpica/files/manipulate-fds-instead-of-FILE.patch 
b/meta/recipes-extended/acpica/files/manipulate-fds-instead-of-FILE.patch
new file mode 100644
index 000..6944bb7
--- /dev/null
+++ b/meta/recipes-extended/acpica/files/manipulate-fds-instead-of-FILE.patch
@@ -0,0 +1,71 @@
+From 33a57979738e5ab13950ec1c0e7298e41ef50929 Mon Sep 17 00:00:00 2001
+From: Patrick Ohly 
+Date: Thu, 23 Feb 2017 18:10:47 +0100
+Subject: [PATCH] aslfiles.c: manipulate fds instead of FILE
+
+Copying what stdout/stderr point to is not portable and fails with
+musl because FILE is an undefined struct.
+
+Instead, use lower-level Unix functions to modify the file that stderr
+writes into. This works on the platforms that Yocto targets.
+
+Upstream-Status: Inappropriate [embedded specific]
+
+Signed-off-by: Patrick Ohly 
+---
+ source/compiler/aslfiles.c | 20 +++-
+ 1 file changed, 11 insertions(+), 9 deletions(-)
+
+diff --git a/source/compiler/aslfiles.c b/source/compiler/aslfiles.c
+index 947e465..7a352b4 100644
+--- a/source/compiler/aslfiles.c
 b/source/compiler/aslfiles.c
+@@ -44,6 +44,11 @@
+ #include "aslcompiler.h"
+ #include "acapps.h"
+ 
++#include 
++#include 
++#include 
++#include 
++
+ #define _COMPONENT  ACPI_COMPILER
+ ACPI_MODULE_NAME("aslfiles")
+ 
+@@ -569,6 +574,8 @@ FlOpenMiscOutputFiles (
+ 
+ if (Gbl_DebugFlag)
+ {
++int fd;
++
+ Filename = FlGenerateFilename (FilenamePrefix, FILE_SUFFIX_DEBUG);
+ if (!Filename)
+ {
+@@ -582,20 +589,15 @@ FlOpenMiscOutputFiles (
+ /* TBD: hide this behind a FlReopenFile function */
+ 
+ Gbl_Files[ASL_FILE_DEBUG_OUTPUT].Filename = Filename;
+-Gbl_Files[ASL_FILE_DEBUG_OUTPUT].Handle =
+-freopen (Filename, "w+t", stderr);
+-
+-if (!Gbl_Files[ASL_FILE_DEBUG_OUTPUT].Handle)
++fd = open(Filename, O_CREAT|O_TRUNC, 
S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
++if (fd < 0 ||
++dup2(fd, fileno(stderr)))
+ {
+-/*
+- * A problem with freopen is that on error,
+- * we no longer have stderr.
+- */
+ Gbl_DebugFlag = FALSE;
+-memcpy (stderr, stdout, sizeof (FILE));
+ FlFileError (ASL_FILE_DEBUG_OUTPUT, ASL_MSG_DEBUG_FILENAME);
+ AslAbort ();
+ }
++Gbl_Files[ASL_FILE_DEBUG_OUTPUT].Handle = stderr;
+ 
+ AslCompilerSignon (ASL_FILE_DEBUG_OUTPUT);
+ AslCompilerFileHeader (ASL_FILE_DEBUG_OUTPUT);
+-- 
+2.1.4
+
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 2/2] ovmf: increase path length limit

2017-02-23 Thread Patrick Ohly
The VfrCompile tool has a hard-coded maximum length for path names
which turned out to be too small by around 20 characters in the
Yocto autobuilder setup. Increasing the maximum by a factor of 4
is relatively easy and makes the problem less likely.

Signed-off-by: Patrick Ohly 
---
 meta/recipes-core/ovmf/ovmf_git.bb | 5 +
 1 file changed, 5 insertions(+)

diff --git a/meta/recipes-core/ovmf/ovmf_git.bb 
b/meta/recipes-core/ovmf/ovmf_git.bb
index 6b3a597..76e836a 100644
--- a/meta/recipes-core/ovmf/ovmf_git.bb
+++ b/meta/recipes-core/ovmf/ovmf_git.bb
@@ -50,6 +50,11 @@ COMPATIBLE_HOST='(i.86|x86_64).*'
 OVMF_SECURE_BOOT_EXTRA_FLAGS ??= ""
 OVMF_SECURE_BOOT_FLAGS = "-DSECURE_BOOT_ENABLE=TRUE 
${OVMF_SECURE_BOOT_EXTRA_FLAGS}"
 
+do_patch[postfuncs] += "fix_path_len"
+fix_path_len () {
+sed -i -e 's/^#define MAX_PATH.*255/#define MAX_PATH 1023/' 
${S}/BaseTools/Source/C/VfrCompile/EfiVfr.h
+}
+
 do_patch_append_class-native() {
 bb.build.exec_func('do_fix_iasl', d)
 bb.build.exec_func('do_fix_toolchain', d)
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH v5 03/12] ovmf: move from meta-luv to OE-core

2017-02-23 Thread Patrick Ohly
On Fri, 2017-02-17 at 18:04 -0800, Khem Raj wrote:
> On 17-02-17 13:10:56, Richard Purdie wrote:
> > On Fri, 2017-01-27 at 16:30 +0100, Patrick Ohly wrote:
> > > From: meta-luv 
> > > 
> > > This is an unmodified copy of
> > > github.com/01org/luv-yocto/meta-luv/recipes-core/ovmf revision
> > > 4be4329.
> > 
> > https://autobuilder.yocto.io/builders/nightly-world/builds/156
> > 
> > which boils down to:
> > 
> > | "gcc-ar" cr 
> > /home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/MdeModulePkg/Library/BootLogoLib/BootLogoLib/OUTPUT/BootLogoLib.lib
> >   
> > @/home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/MdeModulePkg/Library/BootLogoLib/BootLogoLib/OUTPUT/object_files.lst
> > | make: *** 
> > [/home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenanceManagerUiLib/DEBUG/BootMaintenanceManager.c]
> >  Error 2
> > | VfrCompile: ERROR 1003: Invalid option value
> > |   VFR file name 
> > /home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/MdeModulePkg/Library/BootMaintenanceManagerUiLib/BootMaintenanceManagerUiLib/OUTPUT/BootMaintenanceManager.i
> >  is too long.
> > | "gcc-ar" cr 
> > /home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/OvmfPkg/Library/NvVarsFileLib/NvVarsFileLib/OUTPUT/NvVarsFileLib.lib
> >   
> > @/home/pokybuild/yocto-autobuilder/yocto-worker/nightly-world/build/build/tmp/work/x86-pokymllib32-linux/lib32-ovmf/git-r0/git/Build/OvmfIa32/RELEASE_GCC5/IA32/OvmfPkg/Library/NvVarsFileLib/NvVarsFileLib/OUTPUT/object_files.lst
> > 
> > i.e. path length issues.
> > 
> > We saw this on multiple builds :(.
> 
> I wonder why its using gcc-ar that should actually be -gcc-ar
> so probably we need to set AR to point to -gcc-ar, but I would
> like to see if we can use normal ar since  gcc-ar would fail with clang

The actual error wasn't in the gcc-ar invocation but rather the
VfrCompile tool, so for now I haven't done anything about gcc-ar vs. ar.
I have patches for the VfrCompile path length and the acpica+musl issue
which I will send momentarily.

Richard, Ross, they apply on top of the patches that I had sent earlier.

-- 
Best Regards, Patrick Ohly

The content of this message is my personal opinion only and although
I am an employee of Intel, the statements I make here in no way
represent Intel's position on the issue, nor am I authorized to speak
on behalf of Intel on this matter.



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 00/68] Consolidated Pull

2017-02-23 Thread Ross Burton
Long consolidated pull, 100% green on the AB (excluding distrodata).

Note that this contains large amounts of master-next but master-next does
include some patches that are superceded by this series, so I recommend
reviewing this and then rebasing master-next.

Ross

The following changes since commit e436a6398684d2872cb541f1cfb0f67b3618d15a:

  layer.conf: bump version for change in eSDK selftest behaviour (2017-02-19 
09:39:03 -0800)

are available in the git repository at:

  ssh://g...@git.yoctoproject.org/poky-contrib ross/mut

for you to fetch changes up to ccfb9d7b44be942180e4294ef1031e501b5f1187:

  libva: Find the correct wayland-scanner (2017-02-23 15:03:21 +)


Alejandro Hernandez (1):
  eudev: Upgrade to 3.2.1

Amarnath Valluri (1):
  libarchive: Backport upstream fixes.

Andre McCurdy (2):
  arch-arm*.inc: squash whitespace within TUNE_FEATURES strings
  weston: fix LIC_FILES_CHKSUM endline and md5sum for src/compositor.c

Andreas Oberritter (1):
  ffmpeg: Fix the license description

Andy Kling (1):
  dbus: do not use systemctl from host for configure

Athanasios Oikonomou (1):
  lsb: lsb_release script incompatible with busybox head and find

Chen Qi (3):
  cups: upgrade to 2.2.2
  sysstat: upgrade to 11.5.4
  util-linux: upgrade to 2.29.1

Dominic Sacré (2):
  bitbake.conf: Point KERNELORG_MIRROR to cdn.kernel.org
  lib/oe/patch: Support xz-compressed patches

Ed Bartosh (1):
  image_types_wic: fix expansion error

Edwin Plauchu (1):
  swig: upgrade to 3.0.12

Hongxu Jia (1):
  ncurses: 6.0+20160625 -> 6.0+20161126

Humberto Ibarra (1):
  oeqa: fix typo

Jussi Kukkonen (9):
  vte: Upgrade 0.44.2 -> 0.46.1
  util-macros: Upgrade 1.19.0 -> 1.19.1
  presentproto: Upgrade 1.0 -> 1.1
  xauth: Upgrade 1.0.9 -> 1.0.10
  xf86-input-libinput: Upgrade 0.23.0 -> 0.24.0
  xkeyboard-config: Upgrade 2.19 -> 2.20
  libinput: Upgrade 1.6.0 -> 1.6.1
  piglit: Upgrade to current master
  libva: Find the correct wayland-scanner

Khem Raj (4):
  musl: Update to latest
  gdb: Upgrade to 7.12.1
  gmp: Update to 6.1.2
  qemu-native: Point python to python2 on build host

Luck Hoang (1):
  devtool: upgrade: fix error of import recipeutils

Mariano Lopez (2):
  oeqa/runtime/context.py: Fix use of getTarget() with testexport
  selftest/eSDK.py: Cleanup when there is an error in setUpClass

Markus Lehtonen (1):
  scripts/buildstats-diff: fix epoch numbers in --ver-diff

Maxin B. John (1):
  iptables: upgrade to 1.6.1

Mike Crowe (2):
  ccache: Upgrade to v3.3.4
  ccache: Switch to downloading xz tarball

Patrick Ohly (1):
  libarchive: fix bzip2 dependency for native build

Peter Bergin (1):
  useradd-staticids: fix typo for '--expiredate'

Philip Balister (1):
  cmake: Update to 3.7.2.

Richard Purdie (2):
  gcc-cross: Avoid races with gcc_stash_builddir
  depmodwrapper-cross/qemuwrapper-cross: Drop unneeded binutils dependency

Robert P. J. Day (2):
  docbook-xml: correct typo "do_configre"
  kexec-tools/kdump: Correct typo in comment "crashkenrel="

Robert Yang (13):
  terminal.bbclass: export configure vars
  kernel.bbclass: do_deploy requires depmodwrapper
  binconfig.bbclass: fix get_binconfig_mangle()
  libpcre2: add it for newer vte
  python-native: PROVIDES python-io-native
  tcl: extend to nativesdk
  gawk/json-glib/libcheck: extend to nativesdk
  tcl: fix sed in do_install()
  btrfs-tools: only target requires udev
  pigz: set downloadfilename
  eudev: set downloadfilename
  gettext: fix formatting issues
  security_flags.inc: let gettext be secure

Ross Burton (5):
  slang: rewrite recipe to run autoconf
  tremor: remove
  btrfs-tools: don't run autogen.sh
  gstreamer1.0-vaapi: inherit upstream-version-is-even
  unifdef: add UPSTREAM_CHECK_REGEX to filter out development snapshots

Saul Wold (1):
  native.bbclass: populate native recipe with it's files

Stefan Agner (1):
  linux-firmware: Add Marvell sd88xx WiFi firmwares

Stephen Arnold (1):
  gcc-6: Add fix for missing no-PIE flags

Tanu Kaskinen (3):
  alsa-lib: 1.1.2 -> 1.1.3
  alsa-lib: fix softfloat enabling
  alsa-lib: merge alsa-conf-base into alsa-conf

Yuanjie Huang (1):
  gcc: Fix CVE-2016-6131 in libiberty

 meta-selftest/lib/oeqa/runtime/cases/selftest.py   |   6 +-
 meta/classes/binconfig.bbclass |   4 +-
 meta/classes/image_types_wic.bbclass   |   2 +-
 meta/classes/kernel.bbclass|   2 +
 meta/classes/native.bbclass|   5 +
 meta/classes/terminal.bbclass  |   2 +-
 meta/classes/testimage.bbclass |   6 +-
 meta/classes/useradd-staticids.bbclass |   2 +-
 meta/conf/bitbake.conf  

Re: [OE-core] [PATCH 0/3] Fix rpm signing with GPG v2.1

2017-02-23 Thread akuster808

Markus,


On 02/23/2017 02:24 AM, Markus Lehtonen wrote:

This patchset makes signing work with all versions of GPG.  Previously, rpm
package signing in oe-core was not working with GPG v2.1 (which is becoming
more widespread). This was caused by a change in passphrase dialogue handling
of GPG.


Off hand, do you know if Morty would benefit from this?

- armin


[YOCTO #11054]

Markus Lehtonen (3):
   rpm: support customizing gpg command line
   lib/oe/gpg_sign: make gpg version a property of the signer
   lib/oe/gpg_sign: fix rpm signing with gpg > 2.1

  meta/lib/oe/gpg_sign.py| 12 +++---
  .../0001-macros-add-_gpg_sign_cmd_extra_args.patch | 43 ++
  meta/recipes-devtools/rpm/rpm_5.4.16.bb|  1 +
  3 files changed, 51 insertions(+), 5 deletions(-)
  create mode 100644 
meta/recipes-devtools/rpm/rpm/0001-macros-add-_gpg_sign_cmd_extra_args.patch



--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 1/1] selftest/eSDK.py: Cleanup when there is an error in setUpClass

2017-02-23 Thread akuster808

Mariano,


On 02/22/2017 05:12 AM, mariano.lo...@linux.intel.com wrote:

From: Mariano Lopez 

Lately autobuilders are experiencing hangs with selftest,
it seems it is cause if an error happens in setUpClass
method of oeSDKExtSelfTest class because HTTP server
keeps running in background.

Any issue if Morty gets this?
- armin

This patch will ensure tearDownClass will be run if there
is an error in setUpClass.

Signed-off-by: Mariano Lopez 
---
  meta/lib/oeqa/selftest/eSDK.py | 46 +++---
  1 file changed, 25 insertions(+), 21 deletions(-)

diff --git a/meta/lib/oeqa/selftest/eSDK.py b/meta/lib/oeqa/selftest/eSDK.py
index ee1ca6a..b68e997 100644
--- a/meta/lib/oeqa/selftest/eSDK.py
+++ b/meta/lib/oeqa/selftest/eSDK.py
@@ -64,7 +64,7 @@ class oeSDKExtSelfTest(oeSelfTest):
  runCmd("%s -y -d \"%s\"" % (cls.ext_sdk_path, cls.tmpdir_eSDKQA))
  
  cls.env_eSDK = oeSDKExtSelfTest.get_esdk_environment('', cls.tmpdir_eSDKQA)

-
+
  sstate_config="""
  SDK_LOCAL_CONF_WHITELIST = "SSTATE_MIRRORS"
  SSTATE_MIRRORS =  "file://.* http://%s/PATH;
@@ -73,37 +73,41 @@ CORE_IMAGE_EXTRA_INSTALL = "perl"
  
  with open(os.path.join(cls.tmpdir_eSDKQA, 'conf', 'local.conf'), 'a+') as f:

  f.write(sstate_config)
-
  
  @classmethod

  def setUpClass(cls):
-# Start to serve sstate dir
-sstate_dir = get_bb_var('SSTATE_DIR')
-cls.http_service = HTTPService(sstate_dir)
-cls.http_service.start()
+# If there is an exception in setUpClass it will not run tearDownClass
+# method and it leaves HTTP server running forever, so we need to be
+# sure tearDownClass is run.
+try:
+cls.tmpdir_eSDKQA = tempfile.mkdtemp(prefix='eSDKQA')
  
-cls.http_url = "http://127.0.0.1:%d; % cls.http_service.port

-
-cls.image = 'core-image-minimal'
+# Start to serve sstate dir
+sstate_dir = get_bb_var('SSTATE_DIR')
+cls.http_service = HTTPService(sstate_dir)
+cls.http_url = "http://127.0.0.1:%d; % cls.http_service.port
+cls.http_service.start()
  
-cls.tmpdir_eSDKQA = tempfile.mkdtemp(prefix='eSDKQA')

-oeSDKExtSelfTest.generate_eSDK(cls.image)
+cls.image = 'core-image-minimal'
+oeSDKExtSelfTest.generate_eSDK(cls.image)
  
-# Install eSDK

-cls.ext_sdk_path = oeSDKExtSelfTest.get_eSDK_toolchain(cls.image)
-runCmd("%s -y -d \"%s\"" % (cls.ext_sdk_path, cls.tmpdir_eSDKQA))
+# Install eSDK
+cls.ext_sdk_path = oeSDKExtSelfTest.get_eSDK_toolchain(cls.image)
+runCmd("%s -y -d \"%s\"" % (cls.ext_sdk_path, cls.tmpdir_eSDKQA))
  
-cls.env_eSDK = oeSDKExtSelfTest.get_esdk_environment('', cls.tmpdir_eSDKQA)

+cls.env_eSDK = oeSDKExtSelfTest.get_esdk_environment('', 
cls.tmpdir_eSDKQA)
  
-# Configure eSDK to use sstate mirror from poky

-sstate_config="""
+# Configure eSDK to use sstate mirror from poky
+sstate_config="""
  SDK_LOCAL_CONF_WHITELIST = "SSTATE_MIRRORS"
  SSTATE_MIRRORS =  "file://.* http://%s/PATH;
-""" % cls.http_url
-with open(os.path.join(cls.tmpdir_eSDKQA, 'conf', 'local.conf'), 'a+') 
as f:
-f.write(sstate_config)
+""" % cls.http_url
+with open(os.path.join(cls.tmpdir_eSDKQA, 'conf', 'local.conf'), 
'a+') as f:
+f.write(sstate_config)
+except:
+cls.tearDownClass()
+raise
  
-

  @classmethod
  def tearDownClass(cls):
  shutil.rmtree(cls.tmpdir_eSDKQA)


--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] libva: Find the correct wayland-scanner

2017-02-23 Thread Jussi Kukkonen
* Add a patch to make sure wayland-scanner from native sysroot is used
* Depend on wayland-native to get the scanner into the sysroot
* Add a patch to make sure the scanner really is used

Signed-off-by: Jussi Kukkonen 
---
 ...-configure.ac-Use-wayland-scanner-in-PATH.patch |  37 +++
 ...and-Don-t-commit-and-ship-generated-files.patch | 339 +
 meta/recipes-graphics/libva/libva_1.7.3.bb |   6 +-
 3 files changed, 380 insertions(+), 2 deletions(-)
 create mode 100644 
meta/recipes-graphics/libva/files/0001-configure.ac-Use-wayland-scanner-in-PATH.patch
 create mode 100644 
meta/recipes-graphics/libva/files/0001-wayland-Don-t-commit-and-ship-generated-files.patch

diff --git 
a/meta/recipes-graphics/libva/files/0001-configure.ac-Use-wayland-scanner-in-PATH.patch
 
b/meta/recipes-graphics/libva/files/0001-configure.ac-Use-wayland-scanner-in-PATH.patch
new file mode 100644
index 000..a99c225
--- /dev/null
+++ 
b/meta/recipes-graphics/libva/files/0001-configure.ac-Use-wayland-scanner-in-PATH.patch
@@ -0,0 +1,37 @@
+From 0af30602502035155929dd2a14482b82a9747cf8 Mon Sep 17 00:00:00 2001
+From: Jussi Kukkonen 
+Date: Thu, 23 Feb 2017 15:23:15 +0200
+Subject: [PATCH] configure.ac: Use wayland-scanner in PATH
+
+pkg-config will give us the wrong wayland-scanner location.
+Use the one in path instead: it will be from native sysroot.
+
+This is a workaround and should be fixed upstream: preferably
+with the same fix as all the other wayland-scanner users
+(see YOCTO #11100).
+
+Upstream-Status: Inappropriate [workaround]
+Signed-off-by: Jussi Kukkonen 
+---
+ configure.ac | 5 +
+ 1 file changed, 1 insertion(+), 4 deletions(-)
+
+diff --git a/configure.ac b/configure.ac
+index 64eddf2..5536f35 100644
+--- a/configure.ac
 b/configure.ac
+@@ -273,10 +273,7 @@ if test "$enable_wayland" = "yes"; then
+ PKG_CHECK_MODULES([WAYLAND], [wayland-client >= wayland_api_version],
+ [USE_WAYLAND="yes"], [:])
+ if test "$USE_WAYLAND" = "yes"; then
+-
+-WAYLAND_PREFIX=`$PKG_CONFIG --variable=prefix wayland-client`
+-AC_PATH_PROG([WAYLAND_SCANNER], [wayland-scanner],,
+- [${WAYLAND_PREFIX}/bin$PATH_SEPARATOR$PATH])
++AC_PATH_PROG([WAYLAND_SCANNER], [wayland-scanner])
+ 
+ AC_DEFINE([HAVE_VA_WAYLAND], [1],
+   [Defined to 1 if VA/Wayland API is built])
+-- 
+2.1.4
+
diff --git 
a/meta/recipes-graphics/libva/files/0001-wayland-Don-t-commit-and-ship-generated-files.patch
 
b/meta/recipes-graphics/libva/files/0001-wayland-Don-t-commit-and-ship-generated-files.patch
new file mode 100644
index 000..bd97e22
--- /dev/null
+++ 
b/meta/recipes-graphics/libva/files/0001-wayland-Don-t-commit-and-ship-generated-files.patch
@@ -0,0 +1,339 @@
+From 5993a7710cc8fd9a392d5015be5109987a42b498 Mon Sep 17 00:00:00 2001
+From: Jussi Kukkonen 
+Date: Thu, 23 Feb 2017 16:10:09 +0200
+Subject: [PATCH] wayland: Don't commit and ship generated files
+
+I believe shipping wayland-drm-client-protocol.h is wrong: The header
+should always be generated by the wayland-scanner that matches the
+runtime wayland version. Currently when someone clones the repo and
+builds, the shipped version is used.
+
+Upstream-Status: Submitted [https://github.com/01org/libva/pull/33]
+Signed-off-by: Jussi Kukkonen 
+---
+ va/wayland/Makefile.am   |   5 +-
+ va/wayland/wayland-drm-client-protocol.h | 290 ---
+ 2 files changed, 4 insertions(+), 291 deletions(-)
+ delete mode 100644 va/wayland/wayland-drm-client-protocol.h
+
+diff --git a/va/wayland/Makefile.am b/va/wayland/Makefile.am
+index 4f8262c..4ab8d07 100644
+--- a/va/wayland/Makefile.am
 b/va/wayland/Makefile.am
+@@ -53,7 +53,7 @@ protocol_source_h = \
+ noinst_LTLIBRARIES= libva_wayland.la
+ libva_waylandincludedir   = ${includedir}/va
+ libva_waylandinclude_HEADERS  = $(source_h)
+-libva_wayland_la_SOURCES  = $(source_c) $(protocol_source_h)
++libva_wayland_la_SOURCES  = $(source_c)
+ noinst_HEADERS= $(source_h_priv)
+ 
+ # Wayland protocol
+@@ -65,5 +65,8 @@ EXTRA_DIST = \
+   wayland-drm.xml \
+   $(NULL)
+ 
++BUILT_SOURCES = $(protocol_source_h)
++CLEANFILES = $(BUILT_SOURCES)
++
+ # Extra clean files so that maintainer-clean removes *everything*
+ MAINTAINERCLEANFILES = Makefile.in
+diff --git a/va/wayland/wayland-drm-client-protocol.h 
b/va/wayland/wayland-drm-client-protocol.h
+deleted file mode 100644
+index da267e8..000
+--- a/va/wayland/wayland-drm-client-protocol.h
 /dev/null
+@@ -1,290 +0,0 @@
+-/* Generated by wayland-scanner 1.11.90 */
+-
+-#ifndef DRM_CLIENT_PROTOCOL_H
+-#define DRM_CLIENT_PROTOCOL_H
+-
+-#include 
+-#include 
+-#include "wayland-client.h"
+-
+-#ifdef  __cplusplus
+-extern "C" {
+-#endif
+-
+-/**
+- * @page page_drm 

[OE-core] [PATCH 2/2] wic: add more targets to directdisk syslinux config

2017-02-23 Thread Ed Bartosh
Added 3 new targets to directdisk-bootloader-config.cfg to
match hddimg syslinux config.

This is a preparation for dropping hddimg in favor of wic.

[YOCTO #11044]

Signed-off-by: Ed Bartosh 
---
 .../canned-wks/directdisk-bootloader-config.cfg| 28 +-
 1 file changed, 22 insertions(+), 6 deletions(-)

diff --git a/scripts/lib/wic/canned-wks/directdisk-bootloader-config.cfg 
b/scripts/lib/wic/canned-wks/directdisk-bootloader-config.cfg
index a16bd6a..d5a07d2 100644
--- a/scripts/lib/wic/canned-wks/directdisk-bootloader-config.cfg
+++ b/scripts/lib/wic/canned-wks/directdisk-bootloader-config.cfg
@@ -1,11 +1,27 @@
 # This is an example configuration file for syslinux.
-PROMPT 0
-TIMEOUT 10
-
+TIMEOUT 50
 ALLOWOPTIONS 1
 SERIAL 0 115200
+PROMPT 0
+
+UI vesamenu.c32
+menu title Select boot options
+menu tabmsg Press [Tab] to edit, [Return] to select
+
+DEFAULT Graphics console boot
+
+LABEL Graphics console boot
+KERNEL /vmlinuz
+APPEND label=boot root=/dev/sda2 rootwait
+
+LABEL Serial console boot
+KERNEL /vmlinuz
+APPEND label=boot root=/dev/sda2 rootwait console=ttyS0,115200
+
+LABEL Graphics console install
+KERNEL /vmlinuz
+APPEND label=install root=/dev/sda2 rootwait
 
-DEFAULT boot
-LABEL boot
+LABEL Serial console install
 KERNEL /vmlinuz
-APPEND label=boot root=/dev/sda2 rootwait rootfstype=ext4 video=vesafb 
vga=0x318 console=tty0
+APPEND label=install root=/dev/sda2 rootwait console=ttyS0,115200
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 0/2] fix #11044: wic should support multiple boot labels such as boot and install targets

2017-02-23 Thread Ed Bartosh
Hi,

This patchset provides an example of multi-target syslinux config.
It utilizes --configfile bootloader option instead of "traditional" way to
hardcode all configuration details in wic plugin code.

This approach is a preferable way to configure bootloaders in wic. It should
be used for all wic pluins in future.

The following changes since commit 5d96bc6d1af89dda11f3266548fe1547152c86e1:

  image_types_wic: fix expansion error (2017-02-22 15:41:33 +0200)

are available in the git repository at:

  git://git.yoctoproject.org/poky-contrib ed/wic/wip
  http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=ed/wic/wip

Ed Bartosh (2):
  wic: bootimg-pcbios: add support for syslinux vesamenu
  wic: add more targets to directdisk syslinux config

 .../canned-wks/directdisk-bootloader-config.cfg| 28 +-
 scripts/lib/wic/plugins/source/bootimg-pcbios.py   | 20 ++--
 2 files changed, 35 insertions(+), 13 deletions(-)

--
Regards,
Ed
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 0/6] wic: fix for #11017

2017-02-23 Thread Patrick Ohly
On Tue, 2017-02-21 at 17:23 +0200, Ed Bartosh wrote:
> This patchset improves handling of wic native tool dependencies and
> fixes minor bugs in the wic code.

I haven't tested it, but the patches themselves look good to me. Thanks!

-- 
Best Regards, Patrick Ohly

The content of this message is my personal opinion only and although
I am an employee of Intel, the statements I make here in no way
represent Intel's position on the issue, nor am I authorized to speak
on behalf of Intel on this matter.



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] build-perf-test-wrapper.sh: support xml report format

2017-02-23 Thread Markus Lehtonen
Add new command line option '-x' that enbles xml-formatted reports.

Signed-off-by: Markus Lehtonen 
---
 scripts/contrib/build-perf-test-wrapper.sh | 7 ++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/scripts/contrib/build-perf-test-wrapper.sh 
b/scripts/contrib/build-perf-test-wrapper.sh
index f192fcf..240d669 100755
--- a/scripts/contrib/build-perf-test-wrapper.sh
+++ b/scripts/contrib/build-perf-test-wrapper.sh
@@ -33,13 +33,15 @@ Optional arguments:
   -C GIT_REPO   commit results into Git
   -w WORK_DIR   work dir for this script
 (default: GIT_TOP_DIR/build-perf-test)
+  -xcreate xml report (instead of json)
 EOF
 }
 
 
 # Parse command line arguments
 commitish=""
-while getopts "ha:c:C:w:" opt; do
+oe_build_perf_test_extra_opts=()
+while getopts "ha:c:C:w:x" opt; do
 case $opt in
 h)  usage
 exit 0
@@ -52,6 +54,8 @@ while getopts "ha:c:C:w:" opt; do
 ;;
 w)  base_dir=`realpath -s "$OPTARG"`
 ;;
+x)  oe_build_perf_test_extra_opts+=("--xml")
+;;
 *)  usage
 exit 1
 ;;
@@ -129,6 +133,7 @@ fi
 # Run actual test script
 oe-build-perf-test --out-dir "$results_dir" \
--globalres-file "$globalres_log" \
+   "${oe_build_perf_test_extra_opts[@]}" \
--lock-file "$base_dir/oe-build-perf.lock"
 
 # Commit results to git
-- 
2.6.6

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 2/3] gst-player: Upgrade to recent git revision

2017-02-23 Thread Jussi Kukkonen
The update contains a small number of bug fixes. Removed one
upstreamed patch.

gst-player does not have releases: this is the current git master.

Signed-off-by: Jussi Kukkonen 
---
 ...ovide-similar-behaviour-for-quit-and-clos.patch | 32 --
 .../recipes-multimedia/gstreamer/gst-player_git.bb |  3 +-
 2 files changed, 1 insertion(+), 34 deletions(-)
 delete mode 100644 
meta/recipes-multimedia/gstreamer/gst-player/0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch

diff --git 
a/meta/recipes-multimedia/gstreamer/gst-player/0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch
 
b/meta/recipes-multimedia/gstreamer/gst-player/0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch
deleted file mode 100644
index e3f1c4f..000
--- 
a/meta/recipes-multimedia/gstreamer/gst-player/0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch
+++ /dev/null
@@ -1,32 +0,0 @@
-From 220c2659a45dd354270a465c45197970dae5f548 Mon Sep 17 00:00:00 2001
-From: "Maxin B. John" 
-Date: Fri, 5 Aug 2016 17:52:18 +0300
-Subject: [PATCH] gtk-play: provide similar behaviour for quit and close
-
-In x86 targets, gtk-play just pause rather than quitting the application
-when we click the close button (delete-event). Change the callback function
-to get similar behaviour when we click on "Quit" menu option.
-
-Upstream-Status: Accepted
-
-Signed-off-by: Maxin B. John 

- gtk/gtk-play.c | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/gtk/gtk-play.c b/gtk/gtk-play.c
-index a520bef..16afc6b 100644
 a/gtk/gtk-play.c
-+++ b/gtk/gtk-play.c
-@@ -177,7 +177,7 @@ load_from_builder (const gchar * filename, gboolean 
register_sig_handler,
- static void
- delete_event_cb (GtkWidget * widget, GdkEvent * event, GtkPlay * play)
- {
--  gst_player_stop (play->player);
-+  gtk_widget_destroy (GTK_WIDGET (play));
- }
- 
- static void
--- 
-2.4.0
-
diff --git a/meta/recipes-multimedia/gstreamer/gst-player_git.bb 
b/meta/recipes-multimedia/gstreamer/gst-player_git.bb
index 9a023ab..ebc4ae8 100644
--- a/meta/recipes-multimedia/gstreamer/gst-player_git.bb
+++ b/meta/recipes-multimedia/gstreamer/gst-player_git.bb
@@ -8,10 +8,9 @@ SRC_URI = "git://github.com/sdroege/gst-player.git \
file://filechooser.patch;apply=0 \
file://Fix-pause-play.patch;apply=0 \
file://Add-error-signal-emission-for-missing-plugins.patch;apply=0 \
-   
file://0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch \
file://gst-player.desktop"
 
-SRCREV = "ea90e63c1064503f9ba5d59aa4ca604f13ca5def"
+SRCREV = "ee3c226c82767a089743e4e06058743e67f73cdb"
 PV = "0.0.1+git${SRCPV}"
 
 S = "${WORKDIR}/git"
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 1/3] xf86-video-intel: Upgrade to recent git revision

2017-02-23 Thread Jussi Kukkonen
This includes a number of small fixes and some new PCI IDs, no
major changes.

For background, xf86-video-intel does not get releases so
we have to follow git.

Signed-off-by: Jussi Kukkonen 
---
 meta/recipes-graphics/xorg-driver/xf86-video-intel_git.bb | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/meta/recipes-graphics/xorg-driver/xf86-video-intel_git.bb 
b/meta/recipes-graphics/xorg-driver/xf86-video-intel_git.bb
index 3fd6c63..f86de6f 100644
--- a/meta/recipes-graphics/xorg-driver/xf86-video-intel_git.bb
+++ b/meta/recipes-graphics/xorg-driver/xf86-video-intel_git.bb
@@ -9,7 +9,7 @@ Infrastructure (DRI)."
 
 LIC_FILES_CHKSUM = "file://COPYING;md5=8730ad58d11c7bbad9a7066d69f7808e"
 
-SRCREV = "8f33f80100096f7790c7b819ce37a3ed8ce8b5fa"
+SRCREV = "e4fe79cf0d9a05ee3f3a027148ef0aeb2b1b34e1"
 PV = "2.99.917+git${SRCPV}"
 S = "${WORKDIR}/git"
 
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 3/3] x264: Upgrade to stable branch head

2017-02-23 Thread Jussi Kukkonen
Small number of bug fixes and x86 optimizations.

Signed-off-by: Jussi Kukkonen 
---
 meta/recipes-multimedia/x264/x264_git.bb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/meta/recipes-multimedia/x264/x264_git.bb 
b/meta/recipes-multimedia/x264/x264_git.bb
index 64193dc..69f52c2 100644
--- a/meta/recipes-multimedia/x264/x264_git.bb
+++ b/meta/recipes-multimedia/x264/x264_git.bb
@@ -13,9 +13,9 @@ SRC_URI = "git://github.com/mirror/x264;branch=stable \
file://Fix-X32-build-by-disabling-asm.patch \
"
 
-SRCREV = "86b71982e131eaa70125f8d0e725fcade9c4c677"
+SRCREV = "2b741f81e51f92d053d87a49f59ff1026553a0f6"
 
-PV = "r2491+git${SRCPV}"
+PV = "r2731+git${SRCPV}"
 
 S = "${WORKDIR}/git"
 
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 0/3] Upgrades for a few git recipes

2017-02-23 Thread Jussi Kukkonen
Fairly innocent looking git revision upgrades for recipes whose
upstreams do not make releases for one reason or another.

Thanks,
 Jussi

The following changes since commit e436a6398684d2872cb541f1cfb0f67b3618d15a:

  layer.conf: bump version for change in eSDK selftest behaviour (2017-02-19 
09:39:03 -0800)

are available in the git repository at:

  git://git.yoctoproject.org/poky-contrib jku/git-upgrades
  http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=jku/git-upgrades

Jussi Kukkonen (3):
  xf86-video-intel: Upgrade to recent git revision
  gst-player: Upgrade to recent git revision
  x264: Upgrade to stable branch head

 .../xorg-driver/xf86-video-intel_git.bb|  2 +-
 ...ovide-similar-behaviour-for-quit-and-clos.patch | 32 --
 .../recipes-multimedia/gstreamer/gst-player_git.bb |  3 +-
 meta/recipes-multimedia/x264/x264_git.bb   |  4 +--
 4 files changed, 4 insertions(+), 37 deletions(-)
 delete mode 100644 
meta/recipes-multimedia/gstreamer/gst-player/0001-gtk-play-provide-similar-behaviour-for-quit-and-clos.patch

-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] curl: upgrade to 7.53.0

2017-02-23 Thread Oleksandr Kravchuk
Signed-off-by: Oleksandr Kravchuk 
---
 meta/recipes-support/curl/{curl_7.52.1.bb => curl_7.53.0.bb} | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
 rename meta/recipes-support/curl/{curl_7.52.1.bb => curl_7.53.0.bb} (94%)

diff --git a/meta/recipes-support/curl/curl_7.52.1.bb 
b/meta/recipes-support/curl/curl_7.53.0.bb
similarity index 94%
rename from meta/recipes-support/curl/curl_7.52.1.bb
rename to meta/recipes-support/curl/curl_7.53.0.bb
index 2882bc0..130643c 100644
--- a/meta/recipes-support/curl/curl_7.52.1.bb
+++ b/meta/recipes-support/curl/curl_7.53.0.bb
@@ -14,8 +14,8 @@ SRC_URI = "http://curl.haxx.se/download/curl-${PV}.tar.bz2 \
 #
 SRC_URI += " file://configure_ac.patch"
 
-SRC_URI[md5sum] = "dd014df06ff1d12e173de86873f9f77a"
-SRC_URI[sha256sum] = 
"d16185a767cb2c1ba3d5b9096ec54e5ec198b213f45864a38b3bda4bbf87389b"
+SRC_URI[md5sum] = "ede199c63b84df39f42da9da68de85c5"
+SRC_URI[sha256sum] = 
"b2345a8bef87b4c229dedf637cb203b5e21db05e20277c8e1094f0d4da180801"
 
 CVE_PRODUCT = "libcurl"
 inherit autotools pkgconfig binconfig multilib_header
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] "packagegroup-core-tools-debug.bb" seems kind of skimpy

2017-02-23 Thread Burton, Ross
On 23 February 2017 at 12:00, Robert P. J. Day 
wrote:

>   was just asked by a colleague about OE debugging tools, and the file
> packagegroup-core-tools-debug.bb seems kind of light on content:
>
>   MTRACE = ""
>   MTRACE_libc-glibc = "libc-mtrace"
>
>   RDEPENDS_${PN} = "\
> gdb \
> gdbserver \
> strace \
> ${MTRACE} \
> "
>
> are there no other appropriate debugging tools that belong in that
> packagegroup?
>

If you have any suggestions, feel free to send a patch.

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] "packagegroup-core-tools-debug.bb" seems kind of skimpy

2017-02-23 Thread Robert P. J. Day

  was just asked by a colleague about OE debugging tools, and the file
packagegroup-core-tools-debug.bb seems kind of light on content:

  MTRACE = ""
  MTRACE_libc-glibc = "libc-mtrace"

  RDEPENDS_${PN} = "\
gdb \
gdbserver \
strace \
${MTRACE} \
"

are there no other appropriate debugging tools that belong in that
packagegroup?

rday

-- 


Robert P. J. Day Ottawa, Ontario, CANADA
http://crashcourse.ca

Twitter:   http://twitter.com/rpjday
LinkedIn:   http://ca.linkedin.com/in/rpjday


-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] adding recipes to a layer.conf file to simulate(?) an extensible SDK?

2017-02-23 Thread Robert P. J. Day

  caveat: i'm not sure this question is even going to make sense but
i'm going to give it a shot.

  acquaintances have in-house BSP layer for small number of target
boards, and build using OE (actually, wind river linux, but that
distinction doesn't seem relevant). so basic BSP image and *some* user
space apps are incorporated into existing layers and build a number of
working images just fine.

  OTOH, there are some app developers who also need to build for the
same target boards and images, but are *not* using OE/WRL, so they've
been given an appropriate SDK against which to compile their source.
so far, so good, but these developers regularly request more content
in the SDK as they extend their code and need additional shared libs
and header files. fair enough.

  in some cases, they apparently need the developer content related to
things like apache2 and minicom and strace and mtd-utils, and a bunch
of other stuff i find a little puzzling. and the solution until now
(that i was unaware of until recently) has been to add a massive
"IMAGE_INSTALL_append = ..." directive to the layer.conf file, so that
when one runs (and this is the WRL command to generate the SDK):

  $ make export-sdk

one gets an SDK with the developer-related content from all of those
recipes.

  this kind of threw me the first time i saw it. my instant reaction
was, "pretty sure what you want is the WRL version of the extensible
SDK," based on whatever "make" target that corresponds to.

  thoughts? apparently, the above strategy is, technically, working,
but of course it requires a total rebuild of the SDK every time a
developers needs something added. and the idea of adding image recipes
in the layer.conf file seems pretty clearly like a bad idea but, as i
said, it apparently works.

  am i missing something here? as i see it, the obvious (first)
solution is to have the app developers use OE/WRL in the first place,
but that is apparently not an option. so, barring that, the next
solution is to set up an extensible SDK, and extend it as needed.

  i'm just looking for others' opinions on what seems to me to be a
really weird solution to a standard problem.

rday

-- 


Robert P. J. Day Ottawa, Ontario, CANADA
http://crashcourse.ca

Twitter:   http://twitter.com/rpjday
LinkedIn:   http://ca.linkedin.com/in/rpjday


-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 0/6] wic: fix for #11017

2017-02-23 Thread Ed Bartosh
On Thu, Feb 23, 2017 at 12:18:04PM +0200, Ed Bartosh wrote:
> On Wed, Feb 22, 2017 at 10:53:35PM +0200, Ed Bartosh wrote:
> > On Wed, Feb 22, 2017 at 04:38:55PM +, Burton, Ross wrote:
> > > Hi Ed,
> > > 
> > > Something in your latest patchset is breaking selftest:
> > > 
> > > https://autobuilder.yoctoproject.org/main/builders/nightly-wic/builds/626/steps/CreateWicImages/logs/stdio
> > > 
> > > The broken commit is somewhere in ross/mut-wic.  Can you verify that I
> > > didn't leave something out, or otherwise chase this?
> > > 
> > I couldn't reproduce this so far. Will investigate further.
> > 
> > Can you merge this patchset please?
> > http://lists.openembedded.org/pipermail/openembedded-core/2017-February/132854.html
> > 
> > The failure is most probably caused by patchset from this thread.
> > 
> 
> Still not able to reproduce it. It works just fine in my environment.
> This time I used setup as close to AB as I could get: core-image-sato
> image, genericx86-64 machine, clean build.
> 
> [build-genericx86-64 (ed/wic/wip)]$ rm -rf tmp/
> 
> [build-genericx86-64 (ed/wic/wip)]$ bitbake core-image-sato
> WARNING: Host distribution "opensuse-13.2" has not been validated with
> this version of the build system; you may possibly experience unexpected
> failures. It is recommended that you use a tested distribution.
> Parsing recipes: 100%
> |###|
> Time: 0:00:13
> Parsing of 856 .bb files complete (0 cached, 856 parsed). 1322 targets,
> 53 skipped, 0 masked, 0 errors.
> NOTE: Resolving any missing task queue dependencies
> 
> Build Configuration:
> BB_VERSION= "1.33.1"
> BUILD_SYS = "x86_64-linux"
> NATIVELSBSTRING   = "opensuse-13.2"
> TARGET_SYS= "x86_64-poky-linux"
> MACHINE   = "genericx86-64"
> DISTRO= "poky"
> DISTRO_VERSION= "2.2+snapshot-20170222"
> TUNE_FEATURES = "m64 core2"
> TARGET_FPU= ""
> meta
> meta-poky
> meta-yocto-bsp=
> "ed/wic/wip:5d96bc6d1af89dda11f3266548fe1547152c86e1"
> 
> Initialising tasks: 100%
> ||
> Time: 0:00:15
> NOTE: Executing SetScene Tasks
> NOTE: Executing RunQueue Tasks
> NOTE: Tasks Summary: Attempted 6116 tasks of which 2807 didn't need to
> be rerun and all succeeded.
> 
> Summary: There was 1 WARNING message shown.
> 
> [build-genericx86-64 (ed/wic/wip)]$ wic create directdisk -e core-image-sato
> INFO: Creating image(s)...
> 
> INFO: The new image(s) can be found here:
>   ./directdisk-201702231207-sda.direct
> 
> The following build artifacts were used to create the image(s):
>   ROOTFS_DIR:
> /home/ed/git/yocto/poky/build-genericx86-64/tmp/work/genericx86_64-poky-linux/core-image-sato/1.0-r0/rootfs
>   BOOTIMG_DIR:
> /home/ed/git/yocto/poky/build-genericx86-64/tmp/work/core2-64-poky-linux/wic-tools/1.0-r0/recipe-sysroot/usr/share
>   KERNEL_DIR:
> /home/ed/git/yocto/poky/build-genericx86-64/tmp/deploy/images/genericx86-64
>   NATIVE_SYSROOT:
> /home/ed/git/yocto/poky/build-genericx86-64/tmp/work/genericx86_64-poky-linux/core-image-sato/1.0-r0/recipe-sysroot-native
> 
> INFO: The image(s) were created using OE kickstart file:
>   /home/ed/git/yocto/poky/scripts/lib/wic/canned-wks/directdisk.wks
> 
> 
> Could it be because of something in AB setup?
> 

Now I'm pretty sure it's because of AB setup.

I was not able to reproduce it as I used genericx86-64 machine mentioned
on the build page:
https://autobuilder.yoctoproject.org/main/builders/nightly-wic/builds/623

However, AB switched to qemux86-64 machine despite of what's specified.
This is very confusing.

Anyway, the reason of the failure is that AB builds set of tools for wic
in step 12: BuildImages Building syslinux syslinux-native parted-native
gptfdisk-native dosfstools-native mtools-native, but due to RSS those
tools are not accessible by wic. AB should build wic-tools instead.

Regards,
Ed

> > > On 21 February 2017 at 15:23, Ed Bartosh  
> > > wrote:
> > > 
> > > > Hi,
> > > >
> > > > This patchset improves handling of wic native tool dependencies and
> > > > fixes minor bugs in the wic code.
> > > >
> > > > The following changes since commit 9a0ddad5e178d16f302af2d05c3236
> > > > 8572849fd3:
> > > >
> > > >   wic: pluginbase: use global dictionary (2017-02-20 11:58:28 +0200)
> > > >
> > > > are available in the git repository at:
> > > >
> > > >   git://git.yoctoproject.org/poky-contrib ed/wic/wip
> > > >   http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=ed/wic/wip
> > > >
> > > > Ed Bartosh (6):
> > > >   wic: use 2 sysroots to find native executable
> > > >   wic: use image recipe sysroot as default
> > > >   wic: exec_native_cmd: improve debug message
> > > >   wic: exec_native_cmd: fix undefined variable error
> > > >   

[OE-core] [PATCH 3/3] lib/oe/gpg_sign: fix rpm signing with gpg > 2.1

2017-02-23 Thread Markus Lehtonen
We need to check the gpg version and alter its command line options
accordingly.

[YOCTO #11054]

Signed-off-by: Markus Lehtonen 
---
 meta/lib/oe/gpg_sign.py | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/meta/lib/oe/gpg_sign.py b/meta/lib/oe/gpg_sign.py
index 21dc5ea..b635d8b 100644
--- a/meta/lib/oe/gpg_sign.py
+++ b/meta/lib/oe/gpg_sign.py
@@ -32,6 +32,8 @@ class LocalSigner(object):
 
 cmd = self.rpm_bin + " --addsign --define '_gpg_name %s'  " % keyid
 cmd += "--define '_gpg_passphrase %s' " % passphrase
+if self.gpg_version > (2,1,):
+cmd += "--define '_gpg_sign_cmd_extra_args 
--pinentry-mode=loopback' "
 if self.gpg_bin:
 cmd += "--define '%%__gpg %s' " % self.gpg_bin
 if self.gpg_path:
-- 
2.6.6

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 1/3] rpm: support customizing gpg command line

2017-02-23 Thread Markus Lehtonen
Add a new %_gpg_sign_cmd_extra_args macro that allows customizing the
gpg options used when signing rpm packages. This is needed to be able to
sign packages with gpg 2.1 which requires "--pinentry-mode loopback" to
allow non-interactive signing.

[YOCTO #11054]

Signed-off-by: Markus Lehtonen 
---
 .../0001-macros-add-_gpg_sign_cmd_extra_args.patch | 43 ++
 meta/recipes-devtools/rpm/rpm_5.4.16.bb|  1 +
 2 files changed, 44 insertions(+)
 create mode 100644 
meta/recipes-devtools/rpm/rpm/0001-macros-add-_gpg_sign_cmd_extra_args.patch

diff --git 
a/meta/recipes-devtools/rpm/rpm/0001-macros-add-_gpg_sign_cmd_extra_args.patch 
b/meta/recipes-devtools/rpm/rpm/0001-macros-add-_gpg_sign_cmd_extra_args.patch
new file mode 100644
index 000..eb43a87
--- /dev/null
+++ 
b/meta/recipes-devtools/rpm/rpm/0001-macros-add-_gpg_sign_cmd_extra_args.patch
@@ -0,0 +1,43 @@
+From fa9726ff69f86d6a87c4c4bd7e3d2881999a872a Mon Sep 17 00:00:00 2001
+From: Markus Lehtonen 
+Date: Thu, 23 Feb 2017 11:14:20 +0200
+Subject: [PATCH] macros: add %_gpg_sign_cmd_extra_args
+
+Similar to what rpm4 has. This macro can be used to customize the
+gpg command line options when signing packages. This is needed for
+gpg 2.1 which requires "--pinentry-mode loopback" to allow
+non-interactive signing.
+
+Upstream-Status: Pending
+
+Signed-off-by: Markus Lehtonen 
+---
+ macros/macros.in | 5 -
+ 1 file changed, 4 insertions(+), 1 deletion(-)
+
+diff --git a/macros/macros.in b/macros/macros.in
+index 8bc5840..fda3c66 100644
+--- a/macros/macros.in
 b/macros/macros.in
+@@ -524,7 +524,9 @@ $_arbitrary_tags_tests Foo:Bar
+ %_gpg_passphrase_way %{?_gpg_passphrase:--passphrase 
"%{_gpg_passphrase}"}%{!?_gpg_passphrase:--passphrase-fd 3}
+ 
+ %__gpg_check_password_cmd %{__gpg} \
+-  gpg --batch --no-verbose %{_gpg_passphrase_way} -u "%{_gpg_name}" -so -
++  gpg --batch --no-verbose %{_gpg_passphrase_way} \
++  %{?_gpg_sign_cmd_extra_args:%{_gpg_sign_cmd_extra_args}} \
++  -u "%{_gpg_name}" -so -
+ #%__pgp_check_password_cmd%{__pgp} \
+ # pgp +batchmode=on +verbose=0 "%{_pgp_name}" -sf
+ #%__pgp5_check_password_cmd   %{__pgp} \
+@@ -532,6 +534,7 @@ $_arbitrary_tags_tests Foo:Bar
+ 
+ %__gpg_sign_cmd   %{__gpg} \
+   gpg --batch --no-verbose --no-armor %{_gpg_passphrase_way}  
--no-secmem-warning \
++  %{?_gpg_sign_cmd_extra_args:%{_gpg_sign_cmd_extra_args}} \
+   -u "%{_gpg_name}" -sbo %{__signature_filename} %{__plaintext_filename}
+ #%__pgp_sign_cmd  %{__pgp} \
+ # pgp +batchmode=on +verbose=0 +armor=off \
+-- 
+2.10.2
+
diff --git a/meta/recipes-devtools/rpm/rpm_5.4.16.bb 
b/meta/recipes-devtools/rpm/rpm_5.4.16.bb
index 883dbc7..17c5818 100644
--- a/meta/recipes-devtools/rpm/rpm_5.4.16.bb
+++ b/meta/recipes-devtools/rpm/rpm_5.4.16.bb
@@ -119,6 +119,7 @@ SRC_URI += " \
   file://gcc6-stdlib.patch \
   file://0001-system.h-query.c-support-nosignature.patch \
   file://rpm-ensure-rpm2cpio-call-rpm-relocation-code.patch \
+  file://0001-macros-add-_gpg_sign_cmd_extra_args.patch \
 "
 
 # OE specific changes
-- 
2.6.6

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 2/3] lib/oe/gpg_sign: make gpg version a property of the signer

2017-02-23 Thread Markus Lehtonen
Signed-off-by: Markus Lehtonen 
---
 meta/lib/oe/gpg_sign.py | 10 +-
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/meta/lib/oe/gpg_sign.py b/meta/lib/oe/gpg_sign.py
index dcd1990..21dc5ea 100644
--- a/meta/lib/oe/gpg_sign.py
+++ b/meta/lib/oe/gpg_sign.py
@@ -10,6 +10,7 @@ class LocalSigner(object):
 self.gpg_bin = d.getVar('GPG_BIN') or \
   bb.utils.which(os.getenv('PATH'), 'gpg')
 self.gpg_path = d.getVar('GPG_PATH')
+self.gpg_version = self.get_gpg_version()
 self.rpm_bin = bb.utils.which(os.getenv('PATH'), "rpm")
 
 def export_pubkey(self, output_file, keyid, armor=True):
@@ -58,9 +59,7 @@ class LocalSigner(object):
 
 #gpg > 2.1 supports password pipes only through the loopback interface
 #gpg < 2.1 errors out if given unknown parameters
-dots = self.get_gpg_version().split('.')
-assert len(dots) >= 2
-if int(dots[0]) >= 2 and int(dots[1]) >= 1:
+if self.gpg_version > (2,1,):
 cmd += ['--pinentry-mode', 'loopback']
 
 cmd += [input_file]
@@ -87,10 +86,11 @@ class LocalSigner(object):
 
 
 def get_gpg_version(self):
 """Return the gpg version"""
 import subprocess
 try:
-return subprocess.check_output((self.gpg_bin, 
"--version")).split()[2].decode("utf-8")
+ver_str = subprocess.check_output((self.gpg_bin, 
"--version")).split()[2].decode("utf-8")
+return tuple([int(i) for i in ver_str.split('.')])
 except subprocess.CalledProcessError as e:
 raise bb.build.FuncFailed("Could not get gpg version: %s" % e)
 
@@ -87,10 +86,11 @@ class LocalSigner(object):
 
 def get_gpg_version(self):
-"""Return the gpg version"""
+"""Return the gpg version as a tuple of ints"""
 import subprocess
 try:
-- 
2.6.6

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 0/6] wic: fix for #11017

2017-02-23 Thread Ed Bartosh
On Wed, Feb 22, 2017 at 10:53:35PM +0200, Ed Bartosh wrote:
> On Wed, Feb 22, 2017 at 04:38:55PM +, Burton, Ross wrote:
> > Hi Ed,
> > 
> > Something in your latest patchset is breaking selftest:
> > 
> > https://autobuilder.yoctoproject.org/main/builders/nightly-wic/builds/626/steps/CreateWicImages/logs/stdio
> > 
> > The broken commit is somewhere in ross/mut-wic.  Can you verify that I
> > didn't leave something out, or otherwise chase this?
> > 
> I couldn't reproduce this so far. Will investigate further.
> 
> Can you merge this patchset please?
> http://lists.openembedded.org/pipermail/openembedded-core/2017-February/132854.html
> 
> The failure is most probably caused by patchset from this thread.
> 

Still not able to reproduce it. It works just fine in my environment.
This time I used setup as close to AB as I could get: core-image-sato
image, genericx86-64 machine, clean build.

[build-genericx86-64 (ed/wic/wip)]$ rm -rf tmp/

[build-genericx86-64 (ed/wic/wip)]$ bitbake core-image-sato
WARNING: Host distribution "opensuse-13.2" has not been validated with
this version of the build system; you may possibly experience unexpected
failures. It is recommended that you use a tested distribution.
Parsing recipes: 100%
|###|
Time: 0:00:13
Parsing of 856 .bb files complete (0 cached, 856 parsed). 1322 targets,
53 skipped, 0 masked, 0 errors.
NOTE: Resolving any missing task queue dependencies

Build Configuration:
BB_VERSION= "1.33.1"
BUILD_SYS = "x86_64-linux"
NATIVELSBSTRING   = "opensuse-13.2"
TARGET_SYS= "x86_64-poky-linux"
MACHINE   = "genericx86-64"
DISTRO= "poky"
DISTRO_VERSION= "2.2+snapshot-20170222"
TUNE_FEATURES = "m64 core2"
TARGET_FPU= ""
meta
meta-poky
meta-yocto-bsp=
"ed/wic/wip:5d96bc6d1af89dda11f3266548fe1547152c86e1"

Initialising tasks: 100%
||
Time: 0:00:15
NOTE: Executing SetScene Tasks
NOTE: Executing RunQueue Tasks
NOTE: Tasks Summary: Attempted 6116 tasks of which 2807 didn't need to
be rerun and all succeeded.

Summary: There was 1 WARNING message shown.

[build-genericx86-64 (ed/wic/wip)]$ wic create directdisk -e core-image-sato
INFO: Creating image(s)...

INFO: The new image(s) can be found here:
  ./directdisk-201702231207-sda.direct

The following build artifacts were used to create the image(s):
  ROOTFS_DIR:
/home/ed/git/yocto/poky/build-genericx86-64/tmp/work/genericx86_64-poky-linux/core-image-sato/1.0-r0/rootfs
  BOOTIMG_DIR:
/home/ed/git/yocto/poky/build-genericx86-64/tmp/work/core2-64-poky-linux/wic-tools/1.0-r0/recipe-sysroot/usr/share
  KERNEL_DIR:
/home/ed/git/yocto/poky/build-genericx86-64/tmp/deploy/images/genericx86-64
  NATIVE_SYSROOT:
/home/ed/git/yocto/poky/build-genericx86-64/tmp/work/genericx86_64-poky-linux/core-image-sato/1.0-r0/recipe-sysroot-native

INFO: The image(s) were created using OE kickstart file:
  /home/ed/git/yocto/poky/scripts/lib/wic/canned-wks/directdisk.wks


Could it be because of something in AB setup?

Regards,
Ed

> > On 21 February 2017 at 15:23, Ed Bartosh  wrote:
> > 
> > > Hi,
> > >
> > > This patchset improves handling of wic native tool dependencies and
> > > fixes minor bugs in the wic code.
> > >
> > > The following changes since commit 9a0ddad5e178d16f302af2d05c3236
> > > 8572849fd3:
> > >
> > >   wic: pluginbase: use global dictionary (2017-02-20 11:58:28 +0200)
> > >
> > > are available in the git repository at:
> > >
> > >   git://git.yoctoproject.org/poky-contrib ed/wic/wip
> > >   http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=ed/wic/wip
> > >
> > > Ed Bartosh (6):
> > >   wic: use 2 sysroots to find native executable
> > >   wic: use image recipe sysroot as default
> > >   wic: exec_native_cmd: improve debug message
> > >   wic: exec_native_cmd: fix undefined variable error
> > >   wic: add WKS_FILE_DEPENDS variable
> > >   wic: raise WicError instead of calling logger.error
> > >
> > >  meta-selftest/recipes-test/images/wic-image-minimal.bb |  2 +-
> > >  meta/classes/image_types_wic.bbclass   |  2 ++
> > >  scripts/lib/wic/plugins/source/bootimg-pcbios.py   |  4 ++--
> > >  scripts/lib/wic/utils/misc.py  | 13 +
> > >  scripts/wic|  2 +-
> > >  5 files changed, 15 insertions(+), 8 deletions(-)
> > >
> > > --
> > > Regards,
> > > Ed
> > >
> > > --
> > > ___
> > > Openembedded-core mailing list
> > > Openembedded-core@lists.openembedded.org
> > > http://lists.openembedded.org/mailman/listinfo/openembedded-core
> > >
> 
> -- 
> --
> Regards,
> Ed
> -- 
> ___

Re: [OE-core] [PATCH 09/24] boost: update to 1.63.0

2017-02-23 Thread Alexander Kanavin

On 02/23/2017 11:21 AM, André Draszik wrote:

Drop backported 0002-boost-test-execution_monitor.hpp-fix-mips-soft-
float.patch
Rebase consider-hardfp.patch to 0001-When-using-soft-float-on-ARM-we-
should-not-expect-th.patch


I would think that the arm specific soft-float hack 0001-When-using-soft-
float-on-ARM-we-should-not-expect-th.patch is not needed anymore, given that
boost should be able to handle all soft float environments now, but am not
in a position to test this.


Neither am I. If the patch would've been more difficult to rebase, I 
would simply drop it for that reason + inability to test what it does.
That's why sending patches upstream is important (especially non-trivial 
ones); it guarantees that they won't be removed down the road.


Alex

--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 09/24] boost: update to 1.63.0

2017-02-23 Thread André Draszik
On Wed, 2017-02-22 at 16:51 +0200, Alexander Kanavin wrote:
> Drop backported 0002-boost-test-execution_monitor.hpp-fix-mips-soft-
> float.patch
> Rebase consider-hardfp.patch to 0001-When-using-soft-float-on-ARM-we-
> should-not-expect-th.patch

I would think that the arm specific soft-float hack 0001-When-using-soft-
float-on-ARM-we-should-not-expect-th.patch is not needed anymore, given that
boost should be able to handle all soft float environments now, but am not
in a position to test this.

Cheers,
Andre'

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 4/6] libdrm: Upgrade 2.4.74 -> 2.4.75

2017-02-23 Thread Jussi Kukkonen
On 23 February 2017 at 00:22, Burton, Ross  wrote:
>
>
> On 22 February 2017 at 13:02, Jussi Kukkonen 
wrote:
>>
>> * Remove udev from depends (it's not actually used).
>
>
> Is it not used by some of the tests?
>
> packages/corei7-64-poky-linux/libdrm/libdrm-tests: PKGSIZE changed from
350048 to 225496 (-35%)
>   * PV changed from "2.4.74" to "2.4.75"
>   * FILELIST: removed "/usr/bin/dristat /usr/bin/updatedraw
/usr/bin/openclose /usr/bin/name_from_fd /usr/bin/setversion
/usr/bin/getstats /usr/bin/getclient /usr/bin/drmstat /usr/bin/getversion"


No, these were removed as tests for "functionality which is neither being
worked on or actively maintained". Should have mentioned this in the
message.

Jussi
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core